@@ -2,7 +2,7 @@ package GCBorrowings;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -32,7 +32,7 @@ use GCUtils;
 
     use XML::Simple;
 
-    sub importSylpheed
+    sub importClaws
     {
         my ($self, $file) = @_;
         my @result;
@@ -119,9 +119,9 @@ use GCUtils;
                     $dialog->destroy;
                     next;
                 }
-                if ($type eq 'sylpheed')
+                if ($type eq 'claws')
                 {
-                    $self->{borrowers} = $self->importSylpheed($file);
+                    $self->{borrowers} = $self->importClaws($file);
                 }
                 elsif ($type eq 'ldif')
                 {
@@ -165,7 +165,7 @@ use GCUtils;
         $self->{type} = new GCMenuList;
         $self->{type}->setValues([
             {value => 'ldif', displayed => 'LDIF'},
-            {value => 'sylpheed', displayed => 'Sylpheed-Claws'},
+            {value => 'claws', displayed => 'Claws Mail'},
             {value => 'vcard', displayed => 'VCARD'},
         ]);
         my $fileLabel = new GCLabel($parent->{lang}->{BorrowersImportFile});
