@@ -2,7 +2,7 @@ package GCData;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -35,7 +35,10 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
     
     use GCModel;
     use XML::Parser;
-    
+    use File::Copy;
+    use File::Path;
+    use File::Basename;
+
     sub new
     {
         my ($proto, $parent) = @_;
@@ -194,6 +197,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
             }
         }
 
+        $self->{panel}->dataChanged($info);
         my $reloaded = 0;                
         if ($changed)
         {
@@ -203,6 +207,9 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 $self->transformValue($self->{itemArray}[$self->{currentItem}]->{$self->{currentSortField}},
                                       $self->{currentSortField}))
             {
+                # Lists could cache some information. So in any case we have to
+                # update current one.
+                $self->{parent}->{itemsList}->changeCurrent($previous, $info);
                 $self->reloadList;
                 $reloaded = 1;
             }
@@ -227,8 +234,8 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
     
     sub displayCurrent
     {
-        my $self = shift;
-        $self->displayInPanel($self->{panel});
+        my ($self) = @_;
+        $self->displayInPanel($self->{panel}, undef);
     }
     
     sub displayInPanel
@@ -237,7 +244,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         $idx = $self->{currentItem} if $idx == undef;
         return if $self->{currentItem} < 0;
         
-        for my $field (@{$self->{model}->{fieldsNames}})
+        for my $field (@{$self->{model}->{fieldsNotFormatted}})
         {
             $panel->$field($self->{itemArray}[$idx]->{$field});
         }
@@ -390,6 +397,12 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         return ($self->{currentSortOrder}, $self->{currentSortField});        
     }
 
+    sub valueToDisplayed
+    {
+        my ($self, $value, $field) = @_;
+        return $self->{model}->getDisplayedValue($self->{model}->{fieldsInfo}->{$field}->{values}, $value);
+    }
+                
     sub transformValue
     {
         my ($self, $value, $field, $type) = @_;
@@ -397,6 +410,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         $type ||= $self->{model}->{fieldsInfo}->{$field}->{type};
         $value = $self->{parent}->transformTitle($value) if $field eq $self->{model}->{commonFields}->{title};
         $value = GCPreProcess::reverseDate($value) if $type eq 'date';
+        $value = $self->valueToDisplayed($value, $field) if $type eq 'options';
         $value = GCPreProcess::multipleList($value, $type) if $type =~ /list$/o;
         return $value;
     }
@@ -506,7 +520,6 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
             $splash->initProgress if $fullProgress;
             $splash->setItemsTotal($self->{nbItems});
         }
-        
         $self->{parent}->{itemsList}->reset if $self->{parent}->{itemsList};
         
         $self->sortItems;
@@ -601,8 +614,8 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
 
     sub select
     {
-		my ($self, $value, $id, $init) = @_;
-		$self->{parent}->{itemsList}->select($value, $id, $init) unless  $value < -1;
+        my ($self, $value, $id, $init) = @_;
+        $self->{parent}->{itemsList}->select($value, $id, $init) unless  $value < -1;
     }
 
     sub removeCurrentItem
@@ -624,6 +637,25 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
 
         my $oldInfo = splice @{$self->{itemArray}}, $number, 1;
 
+        # Synchronizing list of displayed
+        my $i = scalar @{$self->{selectToIdArray}} - 1;
+        my $after = 1;
+        my $listItem;
+        while ($i >= 0)
+        {
+            if ($self->{selectToIdArray}->[$i] == $number)
+            {
+                splice @{$self->{selectToIdArray}}, $i, 1;
+                $listItem = $i;
+                $after = 0;
+            }
+            elsif ($after)
+            {
+                $self->{selectToIdArray}->[$i]--;
+            }
+            $i--;
+        }
+
         $self->{nbItems}--;
 
         if (!($self->{model}->{preferences}->masterType eq 'generated'))
@@ -639,24 +671,18 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
 
         $self->{panel}->hide if ! $self->{nbItems};
 
-        #$self->{currentItem}-- if $self->{currentItem};
-        #$self->{currentItem}-- if $self->{currentItem} == $self->{nbItems};
-        
-#        my $id = $self->{itemArray}[$self->{currentItem}]->{$self->{model}->{commonFields}->{id}};
-#        $self->{currentId} = $id;
-
-        my ($needReload, $newIdx) = $self->{parent}->{itemsList}->removeItem($number, $prevId, $oldInfo);
+        my ($needReload, $newIdx) = $self->{parent}->{itemsList}->removeItem($listItem, $prevId, $oldInfo);
         $self->{currentId} = $self->{itemArray}[$newIdx]->{$self->{model}->{commonFields}->{id}};
         if ($needReload)
         {
             $self->reloadList;
             $self->{parent}->{itemsList}->grab_focus;
         }
-        $self->{currentItem} = $newIdx;
-
+        $self->{currentItem} = $self->selectToId($newIdx);
         $self->{hasBeenDeleted} = 1;
 
         $self->displayCurrent if $self->{nbItems};
+        $self->setStatus;
     }
 
     sub addItem
@@ -699,13 +725,25 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
     
     sub insertItem
     {
-        my ($self, $info) = @_;
+        my ($self, $info, $generateId) = @_;
 
-        $self->{maxId}++;
-        $self->{itemArray}[$self->{nbItems}]->{$self->{model}->{commonFields}->{id}} = $self->{maxId};
+        # The importer already set the id and we should not generate a new one 
+        my $id;
+        if ($generateId)
+        {
+            $self->{maxId}++;
+            $id = $self->{maxId};
+            $self->{itemArray}[$self->{nbItems}]->{$self->{model}->{commonFields}->{id}} = $id;
+        }
+        else
+        {
+            $id = $info->{$self->{model}->{commonFields}->{id}};
+            $self->{maxId} = $id
+                if $self->{maxId} < $id;
+        }
         for my $field (@{$self->{model}->{fieldsNames}}) 
         {
-            next if $field eq $self->{model}->{commonFields}->{id};
+            next if $field eq $self->{model}->{commonFields}->{id} && $generateId;
             $self->{itemArray}[$self->{nbItems}]->{$field} = $info->{$field};
             if ($self->{model}->{fieldsInfo}->{$field}->{hasHistory})
             {
@@ -717,14 +755,13 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         $self->{nbItems}++;
 
         #$self->{currentId} = $self->{maxId};
-        $self->{toBeDisplayed}->{$self->{maxId}} = 1;
+        $self->{toBeDisplayed}->{$id} = 1;
     }
 
     sub selectToId
     {
-		my ($self, $i) = @_;
-	
-		return $self->{selectToIdArray}[$i];
+        my ($self, $i) = @_;
+        return $self->{selectToIdArray}[$i];
     }
 
     sub setOptions
@@ -781,6 +818,21 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         {
             unlink $_;
         }
+        $self->{oldImagesDirectory} = {};
+        $self->{newImagesDirectory} = undef;
+        $self->{copyImagesWhenChangingDir} = 0;
+    }
+
+    sub setNewImagesDirectory
+    {
+        # $prev is also a parameter because we didn't store it here
+        my ($self, $new, $prev, $withCopy) = @_;
+        $new =~ s|/$||;
+        $self->{newImagesDirectory} = $new;
+        $self->{copyImagesWhenChangingDir} = $withCopy;
+        # We stored the previous one as a hash so it will be easier for tests
+        $prev =~ s|/$||;
+        $self->{oldImagesDirectory}->{$prev} = 1;
     }
 
     sub queryReplace
@@ -919,13 +971,13 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         my $self = shift;
         $self->{currentItem} = -1;
         $self->{maxId} = 0;
-		$self->{itemArray} = [];
-		$self->{information} = {};
-		$self->{selectToIdArray} = [];
+        $self->{itemArray} = [];
+        $self->{information} = {};
+        $self->{selectToIdArray} = [];
         $self->{minRanks} = {};
         $self->{maxRanks} = {};
-		$self->{currentId} = -1;
-		$self->{toBeDisplayed} = {};
+        $self->{currentId} = -1;
+        $self->{toBeDisplayed} = {};
         $self->{panel}->hide if $self->{panel};
         $self->{nbItems} = 0;
         $self->{parent}->{itemsList}->clearCache if $self->{parent}->{itemsList};
@@ -983,7 +1035,8 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
 </collection>
 ';
             close DATA;
-		}
+        }
+
 
         if (! -r $file)
         {
@@ -1005,12 +1058,13 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         $self->clearList;
         $self->{block} = 0;
         $self->{splash} = $splash;
+
         eval
         {
             $globalInstance = $self;
             $self->{inlineModel} = '';
             $self->{inlinePreferences} = '';
-            #my $parser = XML::Parser->new(Style => 'Stream');
+#            my $parser = XML::Parser->new(Style => 'Stream');
             my $parser = XML::Parser->new(Handlers => {
                 Init  => \&StartDocument,
                 Final => \&EndDocument,
@@ -1019,77 +1073,18 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 Char  => \&Text,
             });
             $parser->parsefile($file);
-
-#            use XML::LibXML qw(:all);
-#            my $parser = XML::LibXML->new;
-#            my $doc = $parser->parse_file($file);
-#            my $root = $doc->getDocumentElement();
-#            my $currentCount = 0;
-#            $self->{nbItems} = $root->getAttribute('items');
-#            $self->{splash}->setItemsTotal($self->{nbItems})
-#                if $self->{splash};
-#            if ($root->getAttribute('type') ne 'inline')
-#            {
-#                $self->{parent}->setCurrentModel($root->getAttribute('type'));
-#            }
-#            
-#            for my $node($root->getChildrenByTagName('item'))
-#            {
-#                my $item;
-#                $currentCount++;
-#                for my $data($node->getChildNodes)
-#                {
-#                    next if $data->nodeType eq XML_TEXT_NODE;
-#                    $item->{$data->getName} = $data->textContent;
-#                }
-#                push @{$self->{itemArray}}, $item;
-#                my $id = $item->{$self->{model}->{commonFields}->{id}};
-#                if ($self->{filterSearch}->test($item))
-#                {
-#                    $self->{toBeDisplayed}->{$id} = 1;
-#                }
-#                else
-#                {
-#                    $self->{toBeDisplayed}->{$id} = 0;
-#                }
-#                $self->{splash}->setProgressForItemsLoad($currentCount)
-#                    if $self->{splash};
-#            }
-
-
-
-#            use XML::Twig;
-#
-#            sub item
-#            {
-#                my ($twig, $item) = @_;
-#                #print "Got one\n";
-#            }
-#
-#            my $twig= new XML::Twig( 
-#                                    TwigHandlers => {item => \&item}
-#                                   );            
-#            $twig->parsefile($file);    # build the twig
-#            my $root= $twig->root;           # get the root of the twig (stats)
-#            #my @players= $root->children;    # get the player list
-
-
-
-
-            if ($ENV{GCS_PROFILING} > 0)
-            {
-                my $elapsed;
-                eval '$elapsed = Time::HiRes::tv_interval($initTime)';
-                print "Load time : $elapsed\n";
-            }
-
-
         };
         if ($@)
         {
             print "Fatal error while reading $file: $@\n";
             return 0;
         }
+        elsif ($ENV{GCS_PROFILING} > 0)
+        {
+            my $elapsed;
+            eval '$elapsed = Time::HiRes::tv_interval($initTime)';
+            print "Load time : $elapsed\n";
+        }
 
         for (@{$self->{model}->{fieldsHistory}})
         {
@@ -1118,6 +1113,45 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         return 1;
     }
 
+    sub movePictures
+    {
+        my ($self) = @_;
+        
+        mkpath $self->{newImagesDirectory};
+        my $file;
+        foreach (@{$self->{itemArray}})
+        {
+            foreach my $pic(@{$self->{model}->{fieldsImage}})
+            {
+                $file = GCUtils::getDisplayedImage($_->{$pic},
+                                                   '',
+                                                   $self->{options}->file);
+                # Not moving picture if it is not in the previous directory
+                next if !$file;
+                next if ! exists $self->{oldImagesDirectory}->{Cwd::realpath(dirname($file))};
+                (my $suffix = $file) =~ s/.*?(\.[^.]*)$/$1/;
+                my $new = 
+                    $self->{parent}->getUniqueImageFileName(
+                        $suffix, 
+                        $_->{$self->{model}->{commonFields}->{title}});
+                
+                if ($self->{copyImagesWhenChangingDir})
+                {
+                    copy $file, $new;
+                }
+                else
+                {
+                    move $file, $new;
+                }
+                $_->{$pic} = $new;
+            }
+        }
+        $self->displayCurrent;
+        $self->{newImagesDirectory} = undef;
+        $self->{copyImagesWhenChangingDir} = 0;
+        $self->{oldImagesDirectory} = {};
+    }
+
     sub save
     {
         my ($self, $splash) = @_;
@@ -1129,12 +1163,17 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
             eval '$initTime = [Time::HiRes::gettimeofday()]';
         }
 
+        $self->updateCurrent if ($self->{currentItem} > -1);
+
+        # TODO : Use progress bar for this operation also
+        $self->movePictures
+            if $self->{newImagesDirectory};
+
         if ($splash)
         {
             $splash->initProgress($self->{parent}->{lang}->{StatusSave});
             $splash->setItemsTotal($self->{nbItems});
         }
-        $self->updateCurrent if ($self->{currentItem} > -1);
         $self->addMarkedPictures;
         $self->removeMarkedPictures;
         if (!open DATA, ">".$self->{options}->file)
@@ -1189,7 +1228,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                     = $self->{parent}->transformPicturePath($_->{$pic});
             }
 
-                print DATA ' <item>
+            print DATA ' <item>
 ';
             foreach my $field(@{$self->{model}->{fieldsNames}})
             {
@@ -1357,6 +1396,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 if ($_[1] eq $GCData::inlineCollectionTag)
                 {
                     $anyCap = $prefCap;
+                    $modCap = 0;
                     $globalInstance->{inlineModel} .= '</'.$GCData::collectionTag.'>';
                     if ($globalInstance->{inlinePreferences})
                     {
@@ -1376,6 +1416,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 if ($_[1] eq $GCData::inlinePreferencesTag)
                 {
                     $anyCap = $modCap;
+                    $prefCap = 0;
                     $globalInstance->{inlinePreferences} .= '</'.$GCData::preferencesTag.'>';
                     if ($globalInstance->{inlineModel})
                     {
