@@ -2,7 +2,7 @@ package GCDialogs;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -28,8 +28,9 @@ use utf8;
 
 our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
 
+my $hasAboutDialog = 1;
 eval 'Gtk2::AboutDialog->set_email_hook(undef, undef)';
-my $hasAboutDialog = ($@ ? 0 : 1);
+$hasAboutDialog = 0 if $@;
 
 {
     package GCModalDialog;
@@ -542,6 +543,9 @@ my $hasAboutDialog = ($@ ? 0 : 1);
                               );
 
         $self->{calendar} = new Gtk2::Calendar;
+        $self->{calendar}->signal_connect('day-selected-double-click' => sub {
+            $self->response('ok');
+        });
         
         $self->vbox->pack_start($self->{calendar}, 0, 0, 5);
         $self->vbox->show_all;
@@ -557,13 +561,36 @@ my $hasAboutDialog = ($@ ? 0 : 1);
     package GCPropertiesDialog;
     use base "GCModalDialog";
     
+    sub checkValues
+    {
+        my $self = shift;
+        
+        return $self->{parent}->{lang}->{OptionsPicturesWorkingDirError}
+            if $self->{properties}->{images}->getValue =~ /.%WORKING_DIR%/;
+        return undef;
+    }
+
     sub show
     {
         my $self = shift;
         
         $self->SUPER::show();
         $self->show_all;
-        my $response = $self->run;
+        my $response;
+        while(1)
+        {
+            $response = $self->run;
+            last if $response ne 'ok';
+            my $errorMessage = $self->checkValues;
+            last if !$errorMessage;
+            my  $dialog = Gtk2::MessageDialog->new_with_markup($self->{parent},
+                    [qw/modal destroy-with-parent/],
+                    'error',
+                    'ok',
+                    $errorMessage);
+            $dialog->run;
+            $dialog->destroy;
+        }
         $self->hide;
         return ($response eq 'ok');
     }
@@ -605,7 +632,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
 
         $self->{parent} = $parent;
                               
-        my $table = new Gtk2::Table(11,4,0);
+        my $table = new Gtk2::Table(12,4,0);
         $table->set_row_spacings($GCUtils::halfMargin);
         $table->set_col_spacings($GCUtils::halfMargin);
         $table->set_border_width($GCUtils::margin);
@@ -656,7 +683,15 @@ my $hasAboutDialog = ($@ ? 0 : 1);
         $table->attach($descriptionLabel, 2, 3, 10, 11, 'fill', 'fill', 0, 0);
         $table->attach($self->{properties}->{description}, 3, 4, 10, 11, ['expand', 'fill'], ['expand', 'fill'], 0, 0);
 
-
+        my $picturesDirLabel = new GCLabel($parent->{lang}->{OptionsImages});
+        $self->{properties}->{images} = new GCFile($self, $parent->{lang}->{OptionsImagesTitle}, 'select-folder');
+        $table->attach($picturesDirLabel, 2, 3, 11, 12, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{images}, 3, 4, 11, 12, ['expand', 'fill'], ['fill'], 0, 0);
+#
+#        $self->{labelPicturesWorkingDir} = new GCLabel($parent->{lang}->{OptionsPicturesWorkingDir});
+#        $table->attach($self->{labelPicturesWorkingDir}, 2, 4, 12, 13, 'fill', 'fill', 2*$GCUtils::margin, 0);
+#        $self->{labelPicturesFileBase} = new GCLabel($parent->{lang}->{OptionsPicturesFileBase});
+#        $table->attach($self->{labelPicturesFileBase}, 2, 4, 13, 14, 'fill', 'fill', 2*$GCUtils::margin, 0);
 
         $self->vbox->pack_start($table, 1, 1, 5);
         $self->vbox->show_all;
@@ -1172,6 +1207,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
     use GCGraphicComponents;
     use File::Basename;
     use File::Spec;
+    use Cwd 'realpath';
 
     sub new
     {
@@ -1273,11 +1309,14 @@ my $hasAboutDialog = ($@ ? 0 : 1);
         $file = $ENV{HOME}.'/' if !$file;
 		$file = $dir.'/'.$file if (! File::Spec->file_name_is_absolute( $file ));
         $file =~ s/\//\\/g if ($^O =~ /win32/i);
-        $file = File::Spec->canonpath($file);
-        $self->{dialog}->set_filename($file) if (!$empty && !(-d $file));
-        $self->{dialog}->set_current_folder($file.'/')
-            if (($self->{type} eq 'new') && 
-               (($empty) || (-d $file)));
+        $file = Cwd::realpath($file)
+            if -e $file;
+        eval {
+           $self->{dialog}->set_filename($file) if (!$empty && !(-d $file));
+            $self->{dialog}->set_current_folder($file.'/')
+                if (($self->{type} eq 'new') && 
+                (($empty) || (-d $file)));
+        };
         if ($self->{preview})
         {
             $self->updatePreview($self) if ($self->{type} eq 'old');
