@@ -2,7 +2,7 @@ package GCExport::GCExportHTML;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -304,15 +304,17 @@ use GCExport::GCExportBase;
 
         if ($self->{options}->{withJs})
         {
-            $model =~ s/(\[JS_START\])|(\[JS_END\])//gms;
-            $model =~ s/\[NOJS_START\].*?\[NOJS_END\]//gms;
+            $model =~ s/(\[JAVASCRIPT\])|(\[\/JAVASCRIPT\])//gms;
+            $model =~ s/\[NOJAVASCRIPT\].*?\[\/NOJAVASCRIPT\]//gms;
         }
         else
         {
-            $model =~ s/\[JS_START\].*?\[JS_END\]//gms;
-            $model =~ s/(\[NOJS_START\])|(\[NOJS_END\])//gms;
+            $model =~ s/\[JAVASCRIPT\].*?\[\/JAVASCRIPT\]//gms;
+            $model =~ s/(\[NOJAVASCRIPT\])|(\[\/NOJAVASCRIPT\])//gms;
         }
 
+        # If collection does not manage lendings, remove the LENDING blocks
+        $model =~ s|\[LENDING\](.*?)\[/LENDING\]| $self->{model}->{hasLending} ? $1 : '' |ems;
 
         #Loops
         while ($model =~ m/\[LOOP([0-9]+)?\s+values=([^\s]*?)\s+idx=([^\s]*?)(\s+filter=([^\s]*?))?\]\n?(.*?)\n\s*\[\/LOOP\1\]/gms)
