@@ -2,7 +2,7 @@ package GCExport::GCExportTarGz;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -49,6 +49,11 @@ use GCExport::GCExportBase;
         return $self;
     }
     
+    sub wantsOsSeparator
+    {
+        return 0;
+    }    
+
     sub process
     {
         my ($self, $options) = @_;
