@@ -2,7 +2,7 @@ package GCExport::GCExportTellico;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -45,10 +45,11 @@ use GCExport::GCExportBase;
         #List of collections: http://www.periapsis.org/tellico/doc/collection-type-values.html
         # [ entryTitle, type, extra fields ]
         $self->{models} = {
-                              GCbooks => ['Books', '2', ''],
-                              GCfilms => ['Videos', '3', '<field flags="2" title="Rating" category="Personal" allowed="5;4;3;2;1" format="4" type="3" name="rating" />'],
+                              GCbooks  => ['Books', '2', ''],
+                              GCfilms  => ['Videos', '3', '<field flags="2" title="Rating" category="Personal" allowed="5;4;3;2;1" format="4" type="3" name="rating" />'],
                               GCmusics => ['Music', '4', ''],
-                              GCgames => ['Games', '11', '']
+                              GCcoins  => ['Coin', '8', ''],
+                              GCgames  => ['Games', '11', '']
                           };
         
         return $self;
@@ -153,7 +154,7 @@ use GCExport::GCExportBase;
     sub encodeImage
     {
         my ($self, $file) = @_;
-        my $image = GCUtils::getDisplayedImage($file, $self->{options}->{defaultImage}, $self->{fileName});
+        my $image = GCUtils::getDisplayedImage($file, $self->{options}->{defaultImage}, $self->{original});
         (my $suffix = $image) =~ s/.*?(\.[^.]*)$/$1/;
         $suffix = '.jpeg' if $suffix eq '.jpg';
         my $capsSuffix = uc $suffix;
@@ -431,6 +432,34 @@ use GCExport::GCExportBase;
         return $result;
     }
 
+    sub getGCcoinsItem
+    {
+        my ($self, $item, $number) = @_;
+        my $result;
+        
+        my $frontInfos = $self->encodeImage($item->{front});
+        $self->{imagesInfos}->{$frontInfos->{id}} = $frontInfos;
+        my $backInfos = $self->encodeImage($item->{back});
+        $self->{imagesInfos}->{$backInfos->{id}} = $backInfos;
+
+        $result = '  <entry>
+   <title>'.$self->transformData($item->{name}).'</title>
+   <type>'.$self->transformData($item->{currency}).'</type>
+   <denomination>'.$self->transformData($item->{value}).'</denomination>
+   <year>'.$self->transformData($item->{year}).'</year>
+   <country>'.$self->transformData($item->{country}).'</country>
+   <set>'.(($item->{type} eq 'coin') ? 'true' : 'false').'</set>
+   <pur_date>'.$self->transformData($item->{added}).'</pur_date>
+   <pur_price>'.$self->transformData($item->{estimate}).'</pur_price>
+   <location>'.$self->transformData($item->{location}).'</location>
+   <comments>'.$self->transformData($item->{comments}).'</comments>
+   <obverse>'.$frontInfos->{id}.'</obverse>
+   <reverse>'.$backInfos->{id}.'</reverse>
+  </entry>
+';
+        return $result;
+    }
+
     sub getFooter
     {
         my $self = shift;
@@ -479,4 +508,4 @@ use GCExport::GCExportBase;
     }
 }
 
-1;
\ No newline at end of file
+1;
