@@ -2,7 +2,7 @@ package GCExportImport;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -207,6 +207,8 @@ use GCDialogs;
         foreach $option (@optionsList)
         {
             my $label = $module->getLang->{$option->{label}};
+            $label = $self->{parent}->{model}->getDisplayedText($option->{label})
+                if !$label;
             my $widget;
             my @vExpand = ('fill');
             my $type = $option->{type};
