@@ -2,7 +2,7 @@ package GCGraphicComponents;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -23,7 +23,7 @@ package GCGraphicComponents;
 ###################################################
 use utf8;
 use Gtk2;
-use GCBorrowings;
+#use GCBorrowings;
 
 use strict;
 
@@ -52,6 +52,33 @@ use strict;
     sub selectAll
     {
     }
+
+    sub getTagFromSpan
+    {
+        my ($self, $desc) = @_;
+        my @result = (); #('background' => $self->{background});
+        my @keyvalues = split / /, $desc;
+        foreach (@keyvalues)
+        {
+            /([^=]*)=(.*)/;
+            my $key = $1;
+            my $value = $2;
+            $value =~ s/('|")//g;
+            #"'
+            next if $key =~ /=/;
+            push @result, ($key, $value);
+        }
+        return @result;
+        
+    }
+    
+    sub valueToDisplayed
+    {
+        # 1st parameter is self
+        shift;
+        # Here we don't change the value;
+        return shift;
+    }
 }
 
 {
@@ -207,6 +234,14 @@ use strict;
         $self->set_width_chars($value);
     }
     
+    sub setReadOnly
+    {
+        my $self = shift;
+        $self->set_editable(0);
+        # We change the lock sub so it will never change that
+        *lock = sub { return };
+    }
+
     sub lock
     {
         my ($self, $locked) = @_;
@@ -300,10 +335,6 @@ use strict;
 
         $self->{history} = {'' => 1};
         
-#        $self->entry->signal_connect('activate', sub {
-#            print "Hello\n";
-#        });
-
         bless ($self, $class);
         return $self;
     }
@@ -318,7 +349,8 @@ use strict;
     sub selectAll
     {
         my $self = shift;
-        $self->entry->selectAll;
+        $self->entry->select_region(0, length($self->getValue));
+        $self->entry->grab_focus;
     }
 
     sub getValue
@@ -761,7 +793,7 @@ use strict;
     
     sub new
     {
-        my ($proto, $parent, $title, $type, $withFilter) = @_;
+        my ($proto, $parent, $title, $type, $withFilter, $defaultValue) = @_;
         my $class = ref($proto) || $proto;
     
         my $self = $class->SUPER::new;
@@ -777,11 +809,25 @@ use strict;
         $self->{withFilter} = $withFilter;
 
         $self->{entry} = Gtk2::Entry->new;
-        $self->{button} = Gtk2::Button->new_from_stock('gtk-open');
+        $self->{button} = GCButton->newFromStock('gtk-open');
         $self->{button}->signal_connect('clicked' => sub {
             $self->selectValue;
         });
+        
         $self->pack_start($self->{entry}, 1, 1, 0);
+
+        if ($defaultValue)
+        {
+            $self->{defaultButton} = GCButton->newFromStock('gtk-undo', 0, $parent->{lang}->{PanelRestoreDefault});
+            $parent->{tooltips}->set_tip($self->{defaultButton},
+                $parent->{lang}->{PanelRestoreDefault}.$parent->{lang}->{Separator}.$defaultValue)
+                    if $parent->{tooltips};
+            $self->pack_start($self->{defaultButton}, 0, 0, 0);
+            $self->{defaultButton}->signal_connect('clicked' => sub {
+                $self->setValue($defaultValue);
+            });
+        }
+        
         $self->pack_start($self->{button}, 0, 0, 0);
 
         return $self;
@@ -827,6 +873,31 @@ use strict;
     }
 }
 
+{
+    package GCUrl;
+    
+    @GCUrl::ISA = ('GCFile');
+
+    sub selectValue
+    {
+		my $self = shift;
+		my $url = $self->getValue;
+		return if !$url;
+		$self->{opener}->launch($url, 'url');
+    }
+
+    sub new
+    {
+        my ($proto, $opener) = @_;
+        my $class = ref($proto) || $proto;
+    
+        my $self = $class->SUPER::new(undef, '', 'url');
+        $self->{opener} = $opener;
+        bless ($self, $class);
+        return $self;
+    }
+}
+
 {
     package GCButton;
     
@@ -1202,7 +1273,18 @@ use strict;
                 $self->{entries}->[$i]->clear;
             }
         }
-        push @{$self->{list}->{data}}, \@values;
+        # Check that at least one value is not empty
+        my $isEmpty = 1;
+        for my $val (@values)
+        {
+            if ($val)
+            {
+                $isEmpty = 0;
+                last;
+            }
+        }
+        push @{$self->{list}->{data}}, \@values
+            if !$isEmpty;
     }
 
     sub isEmpty
@@ -1234,7 +1316,6 @@ use strict;
         my $formated = shift;
         if ($formated)
         {
-            print "";
             $result = GCPreProcess::multipleList($result, $self->{number});
         }
         
@@ -1453,7 +1534,7 @@ use strict;
     
     sub clearImage
     {
-		my $self = shift;
+        my $self = shift;
 
         my $imagePrefix = $self->{mainParent}->{imagePrefix};
         if ($self->{imageFile} =~ /(\/|\\)$imagePrefix[0-9]*\./)
@@ -1465,8 +1546,7 @@ use strict;
 
     sub changeImage
     {
-		my ($self, $fileName) = @_;
-
+        my ($self, $fileName) = @_;
         return 0 if $self->{locked};
 
         if (!$fileName)
@@ -1626,7 +1706,8 @@ use strict;
             }
             else
             {
-                $fileName =~ s/^file:\/\/?(.*)\W*$/$1/;
+                $fileName =~ s|^file://?(.*)\W*$|$1|;
+                $fileName =~ s|^/*|| if ($^O =~ /win32/i);
                 $fileName =~ s/.$//ms;
             }
             $self->changeImage($fileName);
@@ -1701,10 +1782,12 @@ use strict;
     
     sub getValue
     {
-        my $self = shift;
+        my ($self, $formatted) = @_;
         my $iter = $self->get_active_iter;
-        return ($self->{model}->get($iter))[0] if $iter;
-        return '';
+        my $value = '';
+        $value = ($self->{model}->get($iter))[0] if $iter;
+        $value = $self->valueToDisplayed($value) if $formatted;
+        return $value;
     }
 
     sub getDisplayedValue
@@ -1875,7 +1958,7 @@ use strict;
         $self->{hboxFill} = new Gtk2::HBox(0,0);
         $self->{hboxFill}->pack_start($self->{label},1,1,0);
         $self->add($self->{hboxFill});
-
+        $self->set_alignment(0,0.5);
         $self->initHistory($listType);
 
         return $self;
@@ -1927,6 +2010,99 @@ use strict;
     }
 }
 
+{
+    package GCColorLink;
+    
+    @GCColorLink::ISA = ('GCColorLabel');
+
+    sub new
+    {
+        my ($proto, $color, $opener) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = $class->SUPER::new($color);
+        bless ($self, $class);
+        $self->{opener} = $opener;
+        $self->signal_connect('button-release-event' => sub {
+            my $value = $self->getValue;
+            return if !$value;
+            $self->{opener}->launch($value, 'url');
+        });
+        $self->signal_connect('enter-notify-event' => sub {
+            $self->window->set_cursor(Gtk2::Gdk::Cursor->new('hand2'))
+                if $self->getValue;
+        });
+        #$self->window->set_cursor(Gtk2::Gdk::Cursor->new('watch'));
+        return $self;
+    }
+}
+
+{
+    package GCColorLongLabel;
+
+    @GCColorLongLabel::ISA = ('Gtk2::TextView', 'GCGraphicComponent');
+
+    sub new
+    {
+        my ($proto, $color) = @_;
+        my $class = ref($proto) || $proto;
+    
+        my $self = $class->SUPER::new;
+        bless ($self, $class);
+
+        $self->set_editable(0);
+        $self->set_wrap_mode('word');
+        $self->{background} = $color;
+        $self->modify_base('normal', $color);
+        $self->modify_bg('normal', $color);
+        $self->set_border_width($GCUtils::halfMargin);
+
+        my $layout = $self->create_pango_layout('G');
+        my (undef, $rect) = $layout->get_pixel_extents;
+        $self->{em} = 1.5 * $rect->{height};        
+
+
+        return $self;
+    }
+    
+    sub acceptMarkup
+    {
+        my $self = shift;
+        return 1;
+    }
+
+    sub setMarkup
+    {
+        my ($self, $text) = @_;
+        
+        $text =~ s/&/&amp;/g;
+        if ($self->{resize})
+        {
+            $self->resize;
+        }
+        else
+        {
+            my $buffer = $self->get_buffer;
+            $self->get_buffer->set_text('');
+            $text =~ s|<span ([^>]*?)>([^<]*?)</span>|$2|;
+            if ($self->{spanTag})
+            {
+                $buffer->get('tag-table')->remove($self->{spanTag});
+            }
+            $self->{spanTag} = $buffer->create_tag('span', $self->getTagFromSpan($1));
+            $buffer->insert_with_tags_by_name ($buffer->get_start_iter, $text, 'span');
+        }
+    }
+
+    sub getValue
+    {
+        my $self = shift;
+
+        (my $label = $self) =~ s/<.*?>(.*?)<\/.*?>/$1/g;
+        return $label;
+    }
+
+}
+
 {
     package GCColorTable;
     
@@ -2012,8 +2188,11 @@ use strict;
             my $j = 0;
             for my $col(@cols)
             {
+                # TODO Optimize GCColorLongLabel. It offers a better display (no scrollbar)
+                # but it slows down the display.
                 my $label = new GCColorLabel($self->{style}->{bgColor});
                 $label->set_padding(6,6);
+                #my $label = new GCColorLongLabel($self->{style}->{bgColor}, '2em');
                 $label->setMarkup('<span '.$self->{style}->{style}.'>'.$col.'</span>');
                 $self->attach($label, $j, $j + 1, $i, $i + 1, ['expand', 'fill'], 'fill', 0, 0);
                 push @{$self->{labels}}, $label;
@@ -2055,6 +2234,7 @@ use strict;
         my $class = ref($proto) || $proto;
     
         my $self = $class->SUPER::new;
+        bless ($self, $class);
 
         $self->{text} = new Gtk2::TextView;
         $self->{text}->set_editable(0);
@@ -2072,27 +2252,9 @@ use strict;
         my (undef, $rect) = $layout->get_pixel_extents;
         $self->{em} = 1.5 * $rect->{height};        
 
-        bless ($self, $class);
-        return $self;
-    }
+        $self->setHeight($height) if $height;
 
-    sub getTagFromSpan
-    {
-        my ($self, $desc) = @_;
-        my @result = (); #('background' => $self->{background});
-        my @keyvalues = split / /, $desc;
-        foreach (@keyvalues)
-        {
-            /([^=]*)=(.*)/;
-            my $key = $1;
-            my $value = $2;
-            $value =~ s/('|")//g;
-            #"'
-            next if $key =~ /=/;
-            push @result, ($key, $value);
-        }
-        return @result;
-        
+        return $self;
     }
     
     sub acceptMarkup
@@ -2142,6 +2304,7 @@ use strict;
     sub AUTOLOAD
     {
         my $self = shift;
+        GCUtils::printStack;
         my $name = our $AUTOLOAD;
         return if $name =~ /::DESTROY$/;
         $name =~ s/.*?::(.*)/$1/;
@@ -2280,11 +2443,13 @@ use strict;
 
     sub new
     {
-        my ($proto, $withImages, $model) = @_;
+        # $advancedFilter: Should we remove some fields that could not be used for grouping
+        my ($proto, $withImages, $model, $advancedFilter) = @_;
         my $class = ref($proto) || $proto;
         my $self = $class->SUPER::new;
         bless($self, $class);
         $self->{withImages} = $withImages;
+        $self->{advancedFilter} = $advancedFilter;
         $self->setModel($model) if $model;
         return $self;
      }
@@ -2297,6 +2462,12 @@ use strict;
         foreach (@{$model->{fieldsNames}})
         {
             next if ($model->{fieldsInfo}->{$_}->{type} eq 'image') && (!$self->{withImages});
+            next if ($self->{advancedFilter}
+                  && (
+                         ($_ eq $model->{commonFields}->{id})
+                      || ($_ eq $model->{commonFields}->{title})
+                     )
+                    );
             next if ! $model->{fieldsInfo}->{$_}->{displayed};
             push @values, {value => $_, 
                            displayed => $model->{fieldsInfo}->{$_}->{displayed}};
