@@ -2,7 +2,7 @@ package GCImport::GCImportBase;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -95,6 +95,11 @@ use GCExportImport;
         return 0;
     }
     
+    sub generateId
+    {
+        return 1;
+    }
+    
     sub getEndInfo
     {
     }
@@ -112,13 +117,14 @@ use GCExportImport;
         my ($self, $options) = @_;
 
         $self->{options} = $options;
-        
+
         $options->{parent}->{items}->updateCurrent;
         my $alreadySaved = 0;
         if ($options->{newList})
         {
             return if !$options->{parent}->checkAndSave;
             $alreadySaved = 1;
+            $options->{parent}->setFile('');
         }
         $self->{options}->{parent}->setWaitCursor($self->{options}->{lang}->{ImportListTitle}.' ('.$options->{file}.')');
         my @tmpArray = @{$self->getItemsArray($options->{file})};
@@ -138,9 +144,10 @@ use GCExportImport;
             $options->{parent}->newList($realModel, $self->{modelAlreadySet}, $alreadySaved);
         }
 
+        my $generateId = $self->generateId;
         foreach (@tmpArray)
         {
-            $options->{parent}->{items}->insertItem($_);
+            $options->{parent}->{items}->insertItem($_, $generateId);
         }
         $self->{options}->{parent}->restoreCursor;
         
