@@ -2,7 +2,7 @@ package GCImport::GCImportTellico;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -46,6 +46,7 @@ use GCImport::GCImportBase;
                               2 => 'GCbooks',
                               3 => 'GCfilms',
                               4 => 'GCmusics',
+                              8 => 'GCcoins',
                               11 => 'GCgames'
                           };
 
@@ -113,10 +114,9 @@ use GCImport::GCImportBase;
     	#Then we test to be sure
     	eval
     	{
-    	   $self->{zip} = Archive::Zip->new($file);
+            $self->{zip} = Archive::Zip->new($file);
     	};
-    	
-        #First we uncompress file
+    	#First we uncompress file
         if (($self->{type} eq 'T') && ($self->{zip}))
         {
             $xml = $self->{zip}->contents('tellico.xml');
@@ -129,7 +129,7 @@ use GCImport::GCImportBase;
             close XML;
         }
 	
-	    #Then we parse XML data
+        #Then we parse XML data
         my $xs = XML::Simple->new;
         my $tellico = $xs->XMLin($xml,
                                  SuppressEmpty => '',
@@ -403,6 +403,35 @@ use GCImport::GCImportBase;
         return \%result;
     }
 
+    sub getGCcoinsItem
+    {
+        my ($self, $entry, $collection) = @_;
+        
+        my $i = 0;
+        my %result;
+    
+        #$result{name} = $entry->{title}->[0];
+        
+        $result{currency} = $entry->{type}->[0];
+        $result{value} = $entry->{denomination}->[0];
+        $result{year} = $entry->{years}->[0]->{year}->[0];
+        $result{country} = $entry->{country}->[0];
+        $result{type} = ($entry->{set}->[0] eq 'true') ? 'coin' : 'banknote';
+        # TODO: Import grade
+        $result{added} = $entry->{pur_date}->[0];
+        $result{estimate} = $entry->{pur_price}->[0];
+        $result{location} = $entry->{location}->[0];
+
+        $result{comments} = $entry->{comments}->[0];
+
+        $result{name} = $result{currency}.' '.$result{value}.' ('.$result{year}.')';
+
+        $result{picture} = $self->getPicture($collection, $entry->{obverse}->[0], $result{name});
+        $result{front} = $self->getPicture($collection, $entry->{obverse}->[0], $result{name}.'_front');
+        $result{back} = $self->getPicture($collection, $entry->{reverse}->[0], $result{name}.'_back');
+        return \%result;
+    }
+
     sub getPicture
     {
         my ($self, $collection, $imageId, $title) = @_;
@@ -454,4 +483,4 @@ use GCImport::GCImportBase;
 
 
 
-1;
\ No newline at end of file
+1;
