@@ -2,7 +2,7 @@ package GCItemsLists;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -135,7 +135,6 @@ use strict;
     sub removeItem
     {
         my ($self, $number) = @_;
-        
         splice @{$self->{list}->{data}}, $number, 1;
         $number-- if $number >= scalar @{$self->{list}->{data}};
         $self->select($number);
@@ -508,7 +507,7 @@ use strict;
     sub createEventBox
     {
         my ($self, $info) = @_;
-    
+
         my $eventBox = new Gtk2::EventBox;
         $eventBox->can_focus(1);
                 
@@ -798,6 +797,7 @@ use strict;
         $self->{preferences}->details($self->{titleField})
             if ! $self->{preferences}->details;
         my @tmpArray = split m/\|/, $self->{preferences}->details;
+        
         $self->{fieldsArray} = \@tmpArray;
         
         $self->{imageIndex} = -1;
@@ -912,7 +912,14 @@ use strict;
 
         if ($self->{generateMaster})
         {
-            $self->{list}->set_expander_column($self->{columns}->{$self->{titleField}});
+            # If title is not displayed, we will use the 1st column to display
+            # the generated masters
+            $self->{generatedField} = $self->{titleField};
+            if (!exists $self->{columns}->{$self->{titleField}})
+            {
+                $self->{generatedField} = $tmpArray[0];
+            }
+            $self->{list}->set_expander_column($self->{columns}->{$self->{generatedField}});
         }
 
         #$self->{list}->get_selection->set_mode ('multiple');
@@ -981,6 +988,14 @@ use strict;
         return $self;
     }
 
+    sub destroy
+    {
+        my $self = shift;
+        # Unlock panel if we locked it when displaying a category
+        $self->{parent}->{panel}->lock(0);
+        $self->SUPER::destroy;
+    }
+
     sub savePreferences
     {
         my ($self, $preferences) = @_;
@@ -1354,6 +1369,10 @@ use strict;
                         $value = GCPreProcess::multipleList($value, $type);
                     }
                 }
+                elsif ($type eq 'options')
+                {
+                    $value = $self->{parent}->{items}->valueToDisplayed($value, $field) || $value;
+                }
                 if ($field eq $self->{titleField})
                 {
                    $value = $self->{parent}->transformTitle($value);
@@ -1464,17 +1483,17 @@ use strict;
         
         while ($master)
         {
-            last if $self->getIterCollection($master) eq $collection;
+            return $master if $self->getIterCollection($master) eq $collection;
             $master = $self->{model}->iter_next($master);
         }
-        return $master;
+        return undef;
     }
 
     sub removeInCollection
     {
         my ($self, $collec, $idx) = @_;
         my $master = $self->findMaster($collec);
-        my $iter = $self->{model}->iter_nth_child($master, 0);
+        my $iter = $self->{model}->iter_nth_child($master, 0) || $master;
         while ($iter)
         {
             last if $idx == $self->convertIterToIdx($iter);
@@ -1598,8 +1617,18 @@ use strict;
         #Creating data;
         my @data = $self->createRowsData($info, $collection, $rank, $self->{nextItemIdx});
 
-        if (($collection eq '') || (! defined $collection) 
-         || (!$self->{groupItems}) || ((ref($collection) eq 'ARRAY') && (! scalar @$collection)))
+        if (
+              ($collection eq '')
+           || (! defined $collection) 
+           || (!$self->{groupItems})
+           || (
+                (ref($collection) eq 'ARRAY')
+             && (
+                  (! scalar @$collection)
+               || ((scalar @$collection == 1) && ($collection->[0] eq ''))
+                )
+              )
+           )
         {
             #Simple entry
             if ($self->{generateMaster})
@@ -1628,6 +1657,7 @@ use strict;
         }
         foreach (@$collection)
         {
+            next if $_ eq '';
             if (exists $self->{alreadyInserted}->{$_})
             {
                 #Master already exists
@@ -1653,7 +1683,7 @@ use strict;
                     $self->{alreadyInserted}->{$_} = 1;
                     my $masterName = $_;
                     my %info = (
-                                   $self->{titleField} => $masterName,
+                                   $self->{generatedField} => $masterName,
                                    $self->{serieField} => $_,
                                    isGeneratedMaster => 1
                                );
@@ -1727,8 +1757,16 @@ use strict;
             }
             if (!$nextIter)
             {
-                $nextIter = $self->{model}->iter_nth_child($parentIter,
-                                                           $self->{model}->iter_n_children($parentIter) - 2);
+                my $nbChildren = $self->{model}->iter_n_children($parentIter);
+                if ($nbChildren > 1)
+                {
+                    $nextIter = $self->{model}->iter_nth_child($parentIter,
+                                                               $self->{model}->iter_n_children($parentIter) - 2);
+                }
+                else
+                {
+                    $nextIter = $self->{model}->iter_nth_child(undef, 0);
+                }
             }
         }
         $self->removeFromModel($currentIter);
@@ -1804,8 +1842,8 @@ use strict;
     {
         my $self = shift;
         
-   		my $path = $self->{list}->get_selection->get_selected_rows;
-		$self->{list}->scroll_to_cell($path) if $path;
+        my $path = $self->{list}->get_selection->get_selected_rows;
+        $self->{list}->scroll_to_cell($path) if $path;
     }
     
     sub changeCurrent
@@ -1917,9 +1955,9 @@ use strict;
                         my @array = ($newCollectionArray);
                         $newCollectionArray = \@array;
                     }
-                    
                     foreach my $collec(@$newCollectionArray)
                     {
+                        next if $collec eq '';
                         push @parents, $self->findMaster($collec);
                         if ($self->{generateMaster})
                         {
@@ -1930,7 +1968,7 @@ use strict;
                                 $parents[-1] = $self->insertAtPosition(undef, $newCollection);
                                 $self->{alreadyInserted}->{$newCollection} = 1;
                                 my %info = (
-                                       $self->{titleField} => $collec,
+                                       $self->{generatedField} => $collec,
                                        $self->{serieField} => $newCollection,
                                        isGeneratedMaster => 1
                                 );
@@ -1948,10 +1986,6 @@ use strict;
                         }
                     }
                     
-                    if ($self->{generateMaster})
-                    {
-                    }
-                    
                 }
 
                 my $childIter = 0;
@@ -1964,8 +1998,13 @@ use strict;
                     $childIter = $cIter if !$childIter;
                 }
                 
-                my $removedCurrent = 0;
-                # When master is generated, we already managed this
+                #First we store if we are removing the one that has been selected
+                $self->{currentRemoved} = ($self->{selectedIterString} eq $self->{currentIterString});
+
+                # For generated master, we could have copies of our item in many places.
+                # So we need to loop on all the previous collections
+                # If we have a real master, we have juste one occurrence, the current one
+
                 if ($self->{generateMaster})
                 {
                     # Now we remove the previous ones for generated master
@@ -1977,19 +2016,21 @@ use strict;
                 }
                 else
                 {
-                    #First we store if we are removing the one that has been selected
-                    $removedCurrent = ($self->{selectedIterString} eq $self->{currentIterString});
                     $self->removeFromModel($currentIter);
-                    $self->{currentRemoved} = $removedCurrent;
                 }
+
                 if ($childIter)
                 {
                     my $childPath = $self->{model}->get_path($childIter);
                     my $rowReference = new Gtk2::TreeRowReference($self->{model}, $childPath);
-                    $self->{currentIterString} = $rowReference->get_path->to_string;
                     $self->{list}->expand_to_path($childPath);
-                    $self->{list}->get_selection->select_iter($childIter) if $removedCurrent;
+                    $self->{list}->get_selection->select_iter($childIter)
+                        if $self->{currentRemoved};
                 }
+                my $iter = $self->{list}->get_selection->get_selected;
+                $self->{selectedIterString} = $self->convertIterToString($iter);
+                $self->{currentIterString} = $self->{selectedIterString};
+                $self->showCurrent;
                 return 0;
             }
         }
@@ -2001,4 +2042,4 @@ use strict;
 }
 
 
-1;
\ No newline at end of file
+1;
