@@ -3,7 +3,7 @@
     
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -24,35 +24,63 @@
 ###################################################
 
 use strict;
+use utf8;
 
 use base 'Exporter';
-our @EXPORT = qw(%langs @langsNames);
+our @EXPORT = qw(%langs);
 
 use File::Basename;
 use FindBin qw($RealBin $Script);
 use GCUtils 'glob';
     
 our %langs;
-our @langsNames = ();
+our $loaded = 0;
 
 sub loadLang
 {
-    my $lang = shift;
+    my ($lang, $nameOnly) = @_;
     
-    eval "use GCLang::${lang}::GCstar";
-    my %tmpLang;
-    eval "%tmpLang = %GCLang::${lang}::lang";
-    $langs{$lang} = \%tmpLang;        
+    if ($nameOnly)
+    {
+        # We directly read the file here to save time and memory
+        open LANG, $ENV{GCS_LIB_DIR}."/GCLang/$lang/GCstar.pm" or return 0;
+        binmode(LANG, ':utf8' );
+        while (<LANG>)
+        {
+            next if !/LangName/;
+            /'?LangName'?\s*=>\s*'?(\w*)'?/;
+            $langs{$lang} = {'LangName' => $1};
+            last;
+        }
+        close LANG;
+    }
+    else
+    {
+        eval "use GCLang::${lang}::GCstar";
+        my %tmpLang;
+        eval "%tmpLang = %GCLang::${lang}::lang";
+        return 0 if !%tmpLang;
+        $langs{$lang} = \%tmpLang;
+    }
+    return 1;
 }
 
 sub loadLangs
 {
     my $lang = shift;
 
-    return if $#langsNames >= 0;
+    return if $loaded;
     if ($lang)
     {
-        loadLang($lang);
+        return 0 if !loadLang($lang);
+        foreach (glob $ENV{GCS_LIB_DIR}.'/GCLang/*')
+        {
+            next if /CVS/ || /pm$/ || /$lang/;
+            my $lang = basename($_);
+            loadLang($lang, 1);
+	    #$langs{$lang} = {'LangName' => $langs{$lang}{LangName}};
+	    #eval "no GCLang::${lang}::GCstar";
+        }
     }
     else
     {
@@ -63,12 +91,8 @@ sub loadLangs
             loadLang($lang);
         }
     }
-
-    foreach (keys %langs)
-    {
-        push @langsNames, $langs{$_}->{LangName};
-    }
-    @langsNames = sort @langsNames;
+    $loaded = 1;
+    return 1;
 }
 
 sub loadPluginsLangs
