@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Hodnocení',
         Format => 'Medium',
         Url => 'Web',
-        Place => 'Umístění',
         Audio => 'Zvuk',
         Video => 'Video formát',
         Trailer => 'Soubor s filmem',
         Serie => 'Sbírka',
         Rank => 'Pořadí',
         Subtitles => 'Titulky',
-        Added => 'Přidáno',
 
         SeenYes => 'Shlédnuto',
         SeenNo => 'Neshlédnuto',
