@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -36,13 +36,17 @@
         NewItem => 'Nová hra',
     
         Id => 'Id',
+        Ean => 'EAN',
         Name => 'Název',
         Platform => 'Platforma',
         Players => 'Počet hráčů',
         Released => 'Datum vydání',
         Editor => 'Vydavatel',
+        Developer => 'Developer',
         Genre => 'Žánr',
         Box => 'Obrázek obalu',
+        Case => 'Case',
+        Manual => 'Instructions manual',
         Rating => 'Hodnocení',
         Completion => 'Dokončeno (%)',
         Description => 'Popis',
@@ -50,7 +54,6 @@
         Code => 'Cheat',
         Effect => 'Účel',
         Secrets => 'Tajemství',
-        Location => 'Lokace',
         Screenshots => 'Snímek ze hry',
         Screenshot1 => 'První snímek ze hry',
         Screenshot2 => 'Druhý snímek ze hry',
