@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -188,6 +188,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Nastavení sbírek',
         'ModelNewType' => 'Nový typ sbírky',
         'ModelName' => 'Název nového typu sbírky:',
+		'ModelFields' => 'Fields',
+		'ModelOptions'	=> 'Options',
+		'ModelFilters'	=> 'Filters',
         'ModelNewField' => 'Nové pole',
         'ModelFieldInformation' => 'Informace',
         'ModelFieldName' => 'Štítek:',
@@ -208,6 +211,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Obrázek',
         'ModelFieldTypeSingleList' => 'Jednoduchý seznam',
         'ModelFieldTypeFile' => 'Soubor',
+        'ModelFieldTypeFormatted' => 'Dependant on other fields',
         'ModelFieldParameters' => 'Parametry',
         'ModelFieldHasHistory' => 'Používat historii',
         'ModelFieldFlat' => 'Zobrazit v jedné řadě',
@@ -294,6 +298,9 @@ http://le-spektre.org',
 		'OptionsStyle' => 'Skin',
         'OptionsDontAsk' => 'Příště se nedotazovat',
         'OptionsPathProgramsGroup' => 'Programy',
+        'OptionsProgramsSystem' => 'Use programs defined by system',
+        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Obrázky',
         'OptionsInternetDataGroup' => 'Import dat',
         'OptionsInternetSettingsGroup' => 'Nastavení',
@@ -306,6 +313,9 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Předpona použitá pro obrázky:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Titul nebo název asociované položky',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Nastavení e-mailových programů',
 
         'ImagesOptionsButton' => 'Nastavení',
@@ -357,6 +367,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Vytvořit novou kolekci',
         'ImportCurrentList' => 'Přidat do stávající kolekce',
         'ImportDropError' => 'Při otevírání souboru se vyskytl problém. Znovu se načte předchozí seznam.',
+        'ImportGenerateId' => 'Generate identifier for each item',
 
         'FileOverwrite' => 'Tento soubor již existuje. Chcete jej přepsat?',
 
@@ -372,6 +383,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Vyberte obrázek',
         'PanelImageNoImage' => 'Bez obrázku',
         'PanelSelectFileTitle' => 'Vyberte soubor',
+        'PanelRestoreDefault' => 'Restore default',
 
         'PanelFrom' =>'Od',
         'PanelTo' =>'Do',
@@ -383,6 +395,8 @@ http://le-spektre.org',
         'PanelDateSelect' => 'Vyberte datum',
         'PanelNobody' => 'Nikomu',
         'PanelUnknown' => 'Neznámo',
+        'PanelAdded' => 'Přidáno',
+        'PanelLocation' => 'Umístění',
 
         'PanelLending' => 'Zápůjčky',
         'PanelBorrower' => 'Dlužník',
