@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -48,11 +48,12 @@
         Read => 'Gelesen',
         Rating => 'Bewertung',
         Acquisition => 'Anschaffungsdatum',
-        Location => 'Ort',
         Edition => 'Edition',
         Format => 'Format',
         Comments => 'Kommentare',
         Url => 'Webseite',
+        Translator => 'Übersetzung',
+        Artist => 'Künstler',
 
         General => 'Allgemein',
         Details => 'Details',
