@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Bewertung',
         Format => 'Format',
         Url => 'Internetseite',
-        Place => 'Ort',
         Audio => 'Audio',
         Video => 'Videoformat',
         Trailer => 'Videodatei',
         Serie => 'Sammlung',
         Rank => 'Teil/Folge',
         Subtitles => 'Untertitel',
-        Added => 'Hinzufügedatum',
 
         SeenYes => 'Film bereits gesehen',
         SeenNo => 'Film noch nicht gesehen',
