@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -36,13 +36,17 @@
         NewItem => 'Neues Spiel',
     
         Id => 'Id',
+        Ean => 'EAN',
         Name => 'Name',
         Platform => 'Plattform',
         Players => 'Anzahl der Spieler',
         Released => 'Erscheinungsdatum',
-        Editor => 'Editor',
+        Editor => 'Herausgeber',
+        Developer => 'Entwickler',
         Genre => 'Genre',
-        Box => 'Bild der Schachtel',
+        Box => 'Bild der Verpackung',
+        Case => 'Originalverpackung',
+        Manual => 'Bedienungsanleitung',
         Rating => 'Bewertung',
         Completion => 'Durchgespielt (%)',
         Description => 'Beschreibung',
@@ -50,7 +54,6 @@
         Code => 'Cheatcode',
         Effect => 'Effekt',
         Secrets => 'Geheimnisse',
-        Location => 'Ort',
         Screenshots => 'Bildschirm Foto',
         Screenshot1 => 'Erstes Bildschirm Foto',
         Screenshot2 => 'Zweites Bildschirm Foto',
