@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -188,6 +188,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Einstellungen von Sammlungen',
         'ModelNewType' => 'Neuer Sammlungstyp',
         'ModelName' => 'Name des Sammlungstypes:',
+		'ModelFields' => 'Felder',
+		'ModelOptions'	=> 'Optionen',
+		'ModelFilters'	=> 'Filter',
         'ModelNewField' => 'Neues Feld',
         'ModelFieldInformation' => 'Information',
         'ModelFieldName' => 'Beschriftung:',
@@ -208,6 +211,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Bild',
         'ModelFieldTypeSingleList' => 'Einfache List',
         'ModelFieldTypeFile' => 'Datei',
+        'ModelFieldTypeFormatted' => 'von anderen Feldern abhängig',
         'ModelFieldParameters' => 'Parameter',
         'ModelFieldHasHistory' => 'Benutze History',
         'ModelFieldFlat' => 'Auf einer Zeile anzeigen',
@@ -294,6 +298,9 @@ http://le-spektre.org',
 		'OptionsStyle' => 'Skin',
         'OptionsDontAsk' => 'Nicht mehr fragen',
         'OptionsPathProgramsGroup' => 'Anwendungsprogramme',
+        'OptionsProgramsSystem' => 'Use programs defined by system',
+        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Bilder',
         'OptionsInternetDataGroup' => 'Datenimport',
         'OptionsInternetSettingsGroup' => 'Einstellungen',
@@ -306,6 +313,9 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Prefix für Bilddateien:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Titel oder Name für das verbundene Element',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Email Programmeinstellung',
 
         'ImagesOptionsButton' => 'Einstellungen',
@@ -357,6 +367,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Eine Neue Sammlung erstellen',
         'ImportCurrentList' => 'Zur aktuellen Sammlung hinzufügen',
         'ImportDropError' => 'Es gab mindestens einen Fehler beim Öffnen der Dateien. Vorherige Liste wird wiederhergestellt.',
+        'ImportGenerateId' => 'ID für jedes Element erzeugen',
 
         'FileOverwrite' => 'Diese Datei existiert bereits. Möchten Sie sie überschreiben?',
 
@@ -372,6 +383,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Wählen Sie ein Bild',
         'PanelImageNoImage' => 'kein Bild',
         'PanelSelectFileTitle' => 'Datei auswählen',
+        'PanelRestoreDefault' => 'Restore default',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
@@ -383,6 +395,8 @@ http://le-spektre.org',
         'PanelDateSelect' => 'Wählen Sie ein Datum',
         'PanelNobody' => 'Niemand',
         'PanelUnknown' => 'Unbekannt',
+        'PanelAdded' => 'Hinzufügedatum',
+        'PanelLocation' => 'Ort',
 
         'PanelLending' => 'Verleih',
         'PanelBorrower'=> 'Entleiher',
