@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Rating',
         Format => 'Media',
         Url => 'Web page',
-        Place => 'Location',
         Audio => 'Audio',
         Video => 'Video format',
         Trailer => 'Video file',
         Serie => 'Serie',
         Rank => 'Rank',
         Subtitles => 'Subtitles',
-        Added => 'Add date',
 
         SeenYes => 'Viewed',
         SeenNo => 'Not viewed',
