@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -189,6 +189,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Collection settings',
         'ModelNewType' => 'New collection type',
         'ModelName' => 'Name of the collection type:',
+		'ModelFields' => 'Fields',
+		'ModelOptions'	=> 'Options',
+		'ModelFilters'	=> 'Filters',
         'ModelNewField' => 'New field',
         'ModelFieldInformation' => 'Information',
         'ModelFieldName' => 'Label:',
@@ -209,6 +212,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Image',
         'ModelFieldTypeSingleList' => 'Simple list',
         'ModelFieldTypeFile' => 'File',
+        'ModelFieldTypeFormatted' => 'Dependant on other fields',
         'ModelFieldParameters' => 'Parameters',
         'ModelFieldHasHistory' => 'Use an history',
         'ModelFieldFlat' => 'Display on one line',
@@ -295,6 +299,9 @@ http://le-spektre.org',
 		'OptionsStyle' => 'Skin',
         'OptionsDontAsk' => 'Don\'t ask anymore',
         'OptionsPathProgramsGroup' => 'Applications',
+        'OptionsProgramsSystem' => 'Use programs defined by system',
+        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Images',
         'OptionsInternetDataGroup' => 'Data import',
         'OptionsInternetSettingsGroup' => 'Settings',
@@ -307,6 +314,10 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Prefix to use for pictures:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Configure mailing programs',
 
         'ImagesOptionsButton' => 'Settings',
@@ -358,6 +369,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Create a new collection',
         'ImportCurrentList' => 'Add to current collection',
         'ImportDropError' => 'There was an error opening at least one file. Previous list will be reloaded.',
+        'ImportGenerateId' => 'Generate identifier for each item',
 
         'FileOverwrite' => 'This file already exists. Do you want to overwrite it?',
 
@@ -374,6 +386,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Select a picture',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Select a file',
+        'PanelRestoreDefault' => 'Restore default',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
@@ -382,9 +395,11 @@ http://le-spektre.org',
         'PanelWebTip' => 'View information on the web about this item',
         'PanelRemoveTip' => 'Remove current item',
 
-        'PanelDateSelect' => 'Select a Date',
+        'PanelDateSelect' => 'Select',
         'PanelNobody' => 'Nobody',
         'PanelUnknown' => 'Unknown',
+        'PanelAdded' => 'Add date',
+        'PanelLocation' => 'Location',
 
         'PanelLending' => 'Lending',
         'PanelBorrower' => 'Borrower',
