@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -48,11 +48,12 @@
         Read => 'Leído',
         Rating => 'Puntuación',
         Acquisition => 'Fecha de adquisición',
-        Location => 'Localización',
         Edition => 'Edición',
         Format => 'Formato',
         Comments => 'Comentarios',
         Url => 'Página web',
+        Translator => 'Translator',
+        Artist => 'Artist',
 
         General => 'General',
         Details => 'Detalles',
