@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Nota',
         Format => 'Soporte',
         Url => 'URL',
-        Place => 'Sitio',
         Audio => 'Audio',
         Video => 'Formato de video',
         Trailer => 'Fichero de video',
         Serie => 'Serie',
         Rank => 'Capítulo',
         Subtitles => 'Subtítulos',
-        Added => 'Añadida el (fecha)',
 
         SeenYes => 'Película ya vista',
         SeenNo => 'Película no vista',
