@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -36,13 +36,17 @@
         NewItem => 'Nuevo juego',
     
         Id => 'Id',
+        Ean => 'EAN',
         Name => 'Nombre',
         Platform => 'Plataforma',
         Players => 'Número de jugadores',
         Released => 'Fecha de publicación',
         Editor => 'Editor',
+        Developer => 'Developer',
         Genre => 'Género',
         Box => 'Portada de la caja',
+        Case => 'Case',
+        Manual => 'Instructions manual',
         Rating => 'Puntuación',
         Completion => 'Completado (%)',
         Description => 'Descripción',
@@ -50,7 +54,6 @@
         Code => 'Código',
         Effect => 'Efecto',
         Secrets => 'Secretos',
-        Location => 'Localización',
         Screenshots => 'Capturas de pantallas',
         Screenshot1 => 'Primera captura',
         Screenshot2 => 'Seguna captura',
