@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -189,6 +189,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Preferencias de la colección',
         'ModelNewType' => 'Nuevo tipo de colección',
         'ModelName' => 'Nombre del tipo de colección:',
+		'ModelFields' => 'Fields',
+		'ModelOptions'	=> 'Options',
+		'ModelFilters'	=> 'Filters',
         'ModelNewField' => 'Nuevo campo',
         'ModelFieldInformation' => 'Información',
         'ModelFieldName' => 'Etiqueta:',
@@ -209,6 +212,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Imagen',
         'ModelFieldTypeSingleList' => 'Lista simple',
         'ModelFieldTypeFile' => 'Fichero',
+        'ModelFieldTypeFormatted' => 'Dependant on other fields',
         'ModelFieldParameters' => 'Parámetros',
         'ModelFieldHasHistory' => 'Usar historial',
         'ModelFieldFlat' => 'Mostrar en una línea',
@@ -295,6 +299,9 @@ http://le-spektre.org',
         'OptionsStyle' => 'Piel',
         'OptionsDontAsk' => 'No preguntar nunca más',
         'OptionsPathProgramsGroup' => 'Aplicaciones',
+        'OptionsProgramsSystem' => 'Use programs defined by system',
+        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Imágenes',
         'OptionsInternetDataGroup' => 'Importar datos',
         'OptionsInternetSettingsGroup' => 'Preferencias',
@@ -307,6 +314,9 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Prefijo para uasr en las imágenes:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Título o nombre del elemento asociado',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Configurar programas de envío correo',
 		       
 	'ImagesOptionsButton' => 'Preferencias',
@@ -358,6 +368,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Crear un nuevo listado',
         'ImportCurrentList' => 'Añadir al listado actual',
         'ImportDropError' => 'Hubo un error abriendo al menos un fichero. Se recargará el listado anterior.',
+        'ImportGenerateId' => 'Generate identifier for each item',
 
         'FileOverwrite' => 'Este fichero existe. ¿Quiere sustituirlo?',
 
@@ -373,6 +384,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Seleccionar una imagen',	
         'PanelImageNoImage' => 'Sin imagen',
         'PanelSelectFileTitle' => 'Seleccione un fichero',
+        'PanelRestoreDefault' => 'Restore default',
 
         'PanelFrom' =>'De',
         'PanelTo' =>'Para',
@@ -384,6 +396,8 @@ http://le-spektre.org',
         'PanelDateSelect' => 'Cambiar la fecha',	
         'PanelNobody' => 'Nadie',	
         'PanelUnknown' => 'Desconocido',	
+        'PanelAdded' => 'Añadida el (fecha)',
+        'PanelLocation' => 'Sitio',
 
         'PanelLending' => 'Préstamo',
         'PanelBorrower' => 'Prestatario',
@@ -432,7 +446,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Películas prestadas',	
         'BorrowedDate' => 'Desde el',	
-        
+
         'MailTitle' => 'Enviar un correo electrónico',	
         'MailFrom' => 'De: ',	
         'MailTo' => 'Para: ',	
