@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Note',
         Format => 'Format',
         Url => 'Page web',
-        Place => 'Emplacement',
         Audio => 'Audio',
         Video => 'Format vidéo',
         Trailer => 'Fichier vidéo',
         Serie => 'Série',
         Rank => 'Rang',
         Subtitles => 'Sous-titres',
-        Added => 'Date d\'ajout',
 
         SeenYes => 'Vu',
         SeenNo => 'Non vu',
