@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -36,13 +36,17 @@
         NewItem => 'Nouveau jeu',
     
         Id => 'Identifiant',
+        Ean => 'EAN',
         Name => 'Nom',
         Platform => 'Plate-forme',
         Players => 'Nombre de joueurs',
         Released => 'Date de sortie',
         Editor => 'Editeur',
+        Developer => 'Développeur',
         Genre => 'Genre',
         Box => 'Boîtier',
+        Case => 'Boîte',
+        Manual => 'Notice',
         Rating => 'Note',
         Completion => 'Avancement (%)',
         Description => 'Description',
@@ -50,7 +54,6 @@
         Code => 'Code',
         Effect => 'Effet',
         Secrets => 'Secrets',
-        Location => 'Emplacement',
         Screenshots => 'Captures',
         Screenshot1 => '1ère capture',
         Screenshot2 => '2ème capture',
