@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -191,6 +191,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Réglages de la collection',
         'ModelNewType' => 'Nouveau type de collection',
         'ModelName' => 'Description du type de collection:',
+		'ModelFields' => 'Fields',
+		'ModelOptions'	=> 'Options',
+		'ModelFilters'	=> 'Filters',
         'ModelNewField' => 'Nouveau champ',
         'ModelFieldInformation' => 'Informations',
         'ModelFieldName' => 'Nom :',
@@ -211,6 +214,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Image',
         'ModelFieldTypeSingleList' => 'Liste simple',
         'ModelFieldTypeFile' => 'Fichier',
+        'ModelFieldTypeFormatted' => 'Dépendant d\'autres champs',
         'ModelFieldParameters' => 'Paramètres',
         'ModelFieldHasHistory' => 'Garder un historique',
         'ModelFieldFlat' => 'Afficher sur une seule ligne',
@@ -297,6 +301,9 @@ http://le-spektre.org',
 		'OptionsStyle' => 'Thème',
         'OptionsDontAsk' => 'Ne plus demander',
         'OptionsPathProgramsGroup' => 'Applications',
+        'OptionsProgramsSystem' => 'Utiliser les programmes définis par le système',
+        'OptionsProgramsUser' => 'Utiliser les programmes spécifiés',
+        'OptionsProgramsSet' => 'Régler les programmes',
         'OptionsPathImagesGroup' => 'Images',
         'OptionsInternetDataGroup' => 'Récupération des données',
         'OptionsInternetSettingsGroup' => 'Réglages',
@@ -309,6 +316,9 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Préfixe à utiliser pour les images :',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Le titre ou le nom de l\'élément associé',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% ou . sera remplacé par le répertoire de la collection (seulement utilisable en début)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% sera remplacé par le fichier contenant la collection sans son suffixe (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% peut seulement être utilisé au début du chemin pour les images',
         'OptionsConfigureMailers' => 'Configurer les clients mail',
 
         'ImagesOptionsButton' => 'Réglages',
@@ -360,6 +370,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Créer une nouvelle liste',
         'ImportCurrentList' => 'Ajouter à la liste courante',
         'ImportDropError' => 'Il y a eu une erreur dans l\'ouverture d\'au moins un fichier. La liste précédente va être rechargée.',
+        'ImportGenerateId' => 'Générer l\'identifiant de chaque élément',
         
         'FileOverwrite' => 'Ce fichier existe. Voulez vous le remplacer ?',
 
@@ -375,6 +386,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Sélectionnez une image',
         'PanelImageNoImage' => 'Pas d\'image',
         'PanelSelectFileTitle' => 'Sélectionnez un fichier',
+        'PanelRestoreDefault' => 'Rétablir défaut',
 
         'PanelFrom' =>'Entre',
         'PanelTo' =>'et',
@@ -383,9 +395,11 @@ http://le-spektre.org',
         'PanelWebTip' => 'Voir la fiche de l\'élément sur Internet',
         'PanelRemoveTip' => 'Supprimer l\'élément affiché ci-dessus',
 
-        'PanelDateSelect' => 'Changer la date',
+        'PanelDateSelect' => 'Changer',
         'PanelNobody' => 'Personne',
         'PanelUnknown' => 'Inconnu',
+        'PanelAdded' => 'Date d\'ajout',
+        'PanelLocation' => 'Emplacement',
 
         'PanelLending' => 'Emprunts',
         'PanelBorrower' => 'Emprunteur',
@@ -434,7 +448,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Eléments empruntés',
         'BorrowedDate' => 'Depuis le',
-        
+
         'MailTitle' => '_Envoyer un e-mail',
         'MailFrom' => 'De : ',
         'MailTo' => 'A : ',
