@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -32,14 +32,14 @@
     our %lang = (
     
         CollectionDescription => 'Movies collection',
-        Items => 'Films',
+        Items => 'Film',
         NewItem => 'Nuovo film',
     
     
         Id => 'Id',
         Title => 'Titolo',
         Date => 'Data',
-        Time => 'Dureta',
+        Time => 'Durata',
         Director => 'Regista',
         Country => 'Nazionalità',
         MinimumAge => 'Età minima',
@@ -54,14 +54,12 @@
         Rating => 'Valutazione',
         Format => 'Tipo',
         Url => 'URL',
-        Place => 'Luogo',
         Audio => 'Audio',
         Video => 'Video format',
         Trailer => 'Video file',
         Serie => 'Serie',
         Rank => 'Rank',
         Subtitles => 'Sottotitoli',
-        Added => 'Add date',
 
         SeenYes => 'Item already viewed',
         SeenNo => 'Item not viewed',
@@ -72,7 +70,7 @@
 
         Main => 'Oggetti principali',
         General => 'Informazioni film',
-        Details => 'Informazioni private',
+        Details => 'Dettagli',
 
         Information => 'Informazioni',
         Languages => 'Lingua',
