@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -36,13 +36,17 @@
         NewItem => 'New game',
     
         Id => 'Id',
+        Ean => 'EAN',
         Name => 'Name',
         Platform => 'Platform',
         Players => 'Number of players',
         Released => 'Release Date',
         Editor => 'Editor',
+        Developer => 'Developer',
         Genre => 'Genre',
         Box => 'Box picture',
+        Case => 'Case',
+        Manual => 'Instructions manual',
         Rating => 'Rating',
         Completion => 'Completion (%)',
         Description => 'Description',
@@ -50,7 +54,6 @@
         Code => 'Code',
         Effect => 'Effect',
         Secrets => 'Secrets',
-        Location => 'Location',
         Screenshots => 'Screenshots',
         Screenshot1 => 'First screenshot',
         Screenshot2 => 'Second screenshot',
@@ -61,7 +64,7 @@
         Howto => 'How to unlock',
 
         General => 'General',
-        Details => 'Details',
+        Details => 'Dettagli',
         Tips => 'Tips',
         Information => 'Information',
 
