@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Ocena',
         Format => 'Media',
         Url => 'Strona internetowa',
-        Place => 'Lokalizacja',
         Audio => 'Dźwięk',
         Video => 'Format obrazu',
         Trailer => 'Plik wideo',
         Serie => 'Kolekcja',
         Rank => 'Ranga',
         Subtitles => 'Napisy',
-        Added => 'Add date',
 
         SeenYes => 'Przeglądane',
         SeenNo => 'Nie przeglądane',
