@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Evaluare',
         Format => 'Mediu',
         Url => 'Web',
-        Place => 'Locaţie',
         Audio => 'Audio',
         Video => 'Format video',
         Trailer => 'Fişier video',
         Serie => 'Colecţie',
         Rank => 'Poziţie',
         Subtitles => 'Subtitrări',
-        Added => 'Add date',
 
         SeenYes => 'Vizionat',
         SeenNo => 'Nevizionat',
