@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -48,11 +48,12 @@
         Read => 'Прочтено?',
         Rating => 'Рейтинг',
         Acquisition => 'Дата получения',
-        Location => 'Местоположение',
         Edition => 'Редакция',
         Format => 'Формат',
         Comments => 'Комментарии',
         Url => 'Узел ВЭБ',
+        Translator => 'Translator',
+        Artist => 'Artist',
 
         General => 'Общее',
         Details => 'Детали',
