@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Рейтинг',
         Format => 'Носитель',
         Url => 'ВЭБ',
-        Place => 'Размещение',
         Audio => 'Аудио',
         Video => 'Видео формат',
         Trailer => 'Видео файл',
         Serie => 'Коллеция',
         Rank => 'Ранг',
         Subtitles => 'Субтитры',
-        Added => 'Добавить дату',
 
         SeenYes => 'Смотрел',
         SeenNo => 'Не смотрел',
