@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -36,13 +36,17 @@
         NewItem => 'Новая игра',
     
         Id => 'Идентификатор',
+        Ean => 'EAN',
         Name => 'Имя',
         Platform => 'Платформа',
         Players => 'Количество игроков',
         Released => 'Дата выпуска',
         Editor => 'Редактор',
+        Developer => 'Developer',
         Genre => 'Жанр',
         Box => 'Изображения коробки',
+        Case => 'Case',
+        Manual => 'Instructions manual',
         Rating => 'Рейтинг',
         Completion => 'Пройдено (%)',
         Description => 'Описание',
@@ -50,10 +54,10 @@
         Code => 'Код',
         Effect => 'Эффект',
         Secrets => 'Секреты',
-        Location => 'Расположение',
         Screenshots => 'Снимки экраны',
         Screenshot1 => 'Первый снимок',
         Screenshot2 => 'Второй снимок',
+        Comments => 'Comments',
         Url => 'ВЭБ страница',
         Unlockables => 'Бонусы',
         Unlockable => 'Бонусы',
