@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -189,6 +189,9 @@ http://le-spektre.org',
         'ModelSettings' => 'настройки коллекции',
         'ModelNewType' => 'новый тип коллекции',
         'ModelName' => 'Имя нового типа коллекции:',
+		'ModelFields' => 'Fields',
+		'ModelOptions'	=> 'Options',
+		'ModelFilters'	=> 'Filters',
         'ModelNewField' => 'Новое поле',
         'ModelFieldInformation' => 'Информация',
         'ModelFieldName' => 'Метка:',
@@ -209,6 +212,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Изображение',
         'ModelFieldTypeSingleList' => 'Простой список',
         'ModelFieldTypeFile' => 'Файл',
+        'ModelFieldTypeFormatted' => 'Dependant on other fields',
         'ModelFieldParameters' => 'Параметры',
         'ModelFieldHasHistory' => 'Использовать историю',
         'ModelFieldFlat' => 'Отображать на одной строке',
@@ -295,6 +299,9 @@ http://le-spektre.org',
 		'OptionsStyle' => 'Шкура',
         'OptionsDontAsk' => 'Больше не спрашивать',
         'OptionsPathProgramsGroup' => 'Приложения',
+        'OptionsProgramsSystem' => 'Use programs defined by system',
+        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Изображения',
         'OptionsInternetDataGroup' => 'Импорт данных',
         'OptionsInternetSettingsGroup' => 'Настройки',
@@ -307,6 +314,9 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Префикс для использования в изображениях:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Заголовок или имя ассоциированного элемента ',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Настройка почтовой программы',
 
         'ImagesOptionsButton' => 'Настройки',
@@ -358,6 +368,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Создать новую коллекцию',
         'ImportCurrentList' => 'Добавить к текущей коллекции',
         'ImportDropError' => 'Произошла ошибка в процессе открытия, по крайней мере в одном файле. Будет загружен предыдущий список.',
+        'ImportGenerateId' => 'Generate identifier for each item',
 
         'FileOverwrite' => 'Такой файл уже существует. Вы хотите перезаписать его?',
 
@@ -373,6 +384,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Выберите картинку',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Выберите файл',
+        'PanelRestoreDefault' => 'Restore default',
 
         'PanelFrom' =>'От',
         'PanelTo' =>'Куда',
@@ -384,6 +396,8 @@ http://le-spektre.org',
         'PanelDateSelect' => 'Выберите дату',
         'PanelNobody' => 'Никто',
         'PanelUnknown' => 'Неизвестно',
+        'PanelAdded' => 'Добавить дату',
+        'PanelLocation' => 'Размещение',
 
         'PanelLending' => 'На руках',
         'PanelBorrower' => 'Должник',
