@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Ocena',
         Format => 'Medij',
         Url => 'Internet',
-        Place => 'Lokacija',
         Audio => 'Zvuk',
         Video => 'Video format',
         Trailer => 'Video fajl',
         Serie => 'Kolekcija',
         Rank => 'Ocena',
         Subtitles => 'Prevod',
-        Added => 'Add date',
 
         SeenYes => 'Gledao',
         SeenNo => 'Neodgledan',
