@@ -186,6 +186,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Collection settings',
         'ModelNewType' => 'New collection type',
         'ModelName' => 'Name of the collection type:',
+		'ModelFields' => 'Fields',
+		'ModelOptions'	=> 'Options',
+		'ModelFilters'	=> 'Filters',
         'ModelNewField' => 'New field',
         'ModelFieldInformation' => 'Information',
         'ModelFieldName' => 'Label:',
@@ -206,6 +209,7 @@ http://le-spektre.org',
         'ModelFieldTypeImage' => 'Image',
         'ModelFieldTypeSingleList' => 'Simple list',
         'ModelFieldTypeFile' => 'File',
+        'ModelFieldTypeFormatted' => 'Dependant on other fields',
         'ModelFieldParameters' => 'Parameters',
         'ModelFieldHasHistory' => 'Use an history',
         'ModelFieldFlat' => 'Display on one line',
@@ -292,6 +296,9 @@ http://le-spektre.org',
 		'OptionsStyle' => 'Promena izgleda',
         'OptionsDontAsk' => 'Ne pitaj više',
         'OptionsPathProgramsGroup' => 'Applications',
+        'OptionsProgramsSystem' => 'Use programs defined by system',
+        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Images',
         'OptionsInternetDataGroup' => 'Data import',
         'OptionsInternetSettingsGroup' => 'Settings',
@@ -304,6 +311,9 @@ http://le-spektre.org',
         'OptionsPicturesFormat' => 'Prefix to use for pictures:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Configure mailing programs',
 
         'ImagesOptionsButton' => 'Podešavanja',
@@ -355,6 +365,7 @@ http://le-spektre.org',
         'ImportNewList' => 'Napravi novu kolekciju',
         'ImportCurrentList' => 'Dodaj u trenutnu kolekciju',
         'ImportDropError' => 'Došlo je do greške pri otvaranju najmanje jednog fajla. Učitaće se prethodna lista.',
+        'ImportGenerateId' => 'Generate identifier for each item',
 
         'FileOverwrite' => 'Ovaj fajl već postoji. Da li želite da ga zamenite novim fajlom?',
 
@@ -370,6 +381,7 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Odaberi sliku',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Odaberi fajl',
+        'PanelRestoreDefault' => 'Restore default',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
@@ -381,6 +393,8 @@ http://le-spektre.org',
         'PanelDateSelect' => 'Odaberi datum',
         'PanelNobody' => 'Niko',
         'PanelUnknown' => 'Nepoznat',
+        'PanelAdded' => 'Add date',
+        'PanelLocation' => 'Lokacija',
 
         'PanelLending' => 'Pozajmljivanje',
         'PanelBorrower' => 'Pozajmio',
@@ -502,4 +516,4 @@ http://le-spektre.org',
         'AdvancedSearchCriteria' => 'Criteria',
     );
 }
-1;
\ No newline at end of file
+1;
