@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,14 +54,12 @@
         Rating => 'Puan',
         Format => 'Medya',
         Url => 'Web',
-        Place => 'Yer',
         Audio => 'Ses',
         Video => 'Video formatı',
         Trailer => 'Video dosyası',
         Serie => 'Koleksiyon',
         Rank => 'Sıralama',
         Subtitles => 'Altyazı(lar)',
-        Added => 'Add date',
 
         SeenYes => 'İzlendi',
         SeenNo => 'İzlenmedi',
