@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -36,13 +36,17 @@
         NewItem => 'Yeni Oyun',
         
         Id => 'No',
+        Ean => 'EAN',
         Name => 'Ad',
         Platform => 'Platform',
         Players => 'Oyuncu Sayısı',
         Released => 'Yayınlanma Tarihi',
         Editor => 'Editör',
+        Developer => 'Developer',
         Genre => 'Kategori',
         Box => 'Kapak Resmi',
+        Case => 'Case',
+        Manual => 'Instructions manual',
         Rating => 'Puan',
         Completion => 'Tamamlanma (%)',
         Description => 'Bilgi',
@@ -50,7 +54,6 @@
         Code => 'Kod',
         Effect => 'Etki',
         Secrets => 'Sırlar',
-        Location => 'Yer',
         Screenshots => 'Ekran Görüntüleri',
         Screenshot1 => '1. Ekran Görüntüsü',
         Screenshot2 => '2. Ekran Görüntüsü',
