@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -193,6 +193,9 @@ http://le-spektre.org\'a aittir.',
         'ModelSettings' => 'Collection settings',
         'ModelNewType' => 'New collection type',
         'ModelName' => 'Name of the collection type:',
+		'ModelFields' => 'Fields',
+		'ModelOptions'	=> 'Options',
+		'ModelFilters'	=> 'Filters',
         'ModelNewField' => 'New field',
         'ModelFieldInformation' => 'Information',
         'ModelFieldName' => 'Label:',
@@ -213,6 +216,7 @@ http://le-spektre.org\'a aittir.',
         'ModelFieldTypeImage' => 'Image',
         'ModelFieldTypeSingleList' => 'Simple list',
         'ModelFieldTypeFile' => 'File',
+        'ModelFieldTypeFormatted' => 'Dependant on other fields',
         'ModelFieldParameters' => 'Parameters',
         'ModelFieldHasHistory' => 'Use an history',
         'ModelFieldFlat' => 'Display on one line',
@@ -299,6 +303,9 @@ http://le-spektre.org\'a aittir.',
 		'OptionsStyle' => 'Arayüz',
         'OptionsDontAsk' => 'Bir daha sorma',
         'OptionsPathProgramsGroup' => 'Yazılımlar',
+        'OptionsProgramsSystem' => 'Use programs defined by system',
+        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Resimler',
         'OptionsInternetDataGroup' => 'Veri alma',
         'OptionsInternetSettingsGroup' => 'Ayarlar',
@@ -311,6 +318,9 @@ http://le-spektre.org\'a aittir.',
         'OptionsPicturesFormat' => 'Prefix to use for pictures:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
+        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
+        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
+        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
         'OptionsConfigureMailers' => 'Configure mailing programs',
 
         'ImagesOptionsButton' => 'Ayarlar',
@@ -362,6 +372,7 @@ http://le-spektre.org\'a aittir.',
         'ImportNewList' => 'Yeni veritabanı oluştur',
         'ImportCurrentList' => 'Açık olan veritabanına aktar',
         'ImportDropError' => 'Dosyanın açılmasında sorun çıktı. Bir önceki veritabanı yüklenecek.',
+        'ImportGenerateId' => 'Generate identifier for each item',
 
         'FileOverwrite' => 'Bu dosya zaten var. Üzerine yazmak istediğinizden emin misiniz?',
 
@@ -378,6 +389,7 @@ http://le-spektre.org\'a aittir.',
         'PanelImageTitle' => 'Kapak seç',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Dosya Seçiniz',
+        'PanelRestoreDefault' => 'Restore default',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
@@ -389,6 +401,8 @@ http://le-spektre.org\'a aittir.',
         'PanelDateSelect' => 'Tarih Seçiniz',
         'PanelNobody' => 'Kimse',
         'PanelUnknown' => 'Bilinmiyor',
+        'PanelAdded' => 'Add date',
+        'PanelLocation' => 'Yer',
 
         'PanelLending' => 'Ödünç',
         'PanelBorrower' => 'Ödünç Alan',
