@@ -2,7 +2,7 @@ package GCMainWindow;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -31,6 +31,7 @@ use Gtk2;
     package GCFrame;
     use base "Gtk2::Window";
 
+    # Internal modules
     use GCDialogs;
     use GCItemsLists;
     use GCPlugins;
@@ -53,13 +54,16 @@ use Gtk2;
     use GCBookmarks;
     #use GCGenres;
 
+    # External modules
     use LWP;
     use URI::Escape;
     use File::Basename;
     use File::Spec;
     use File::Copy;
+    use File::Path;
     use IO::Handle;
     use Storable qw(store_fd fd_retrieve);
+    use File::Temp qw(tempdir);
 
     sub beforeDestroy
     {
@@ -101,16 +105,16 @@ use Gtk2;
     sub deleteCurrentItem
     {
         my $self = shift;
-		my $response = 'yes';
-	    my $confirm = 0;
+        my $response = 'yes';
+        my $confirm = 0;
 
-		if ($self->{options}->confirm)
-		{
-		    my  $dialog = Gtk2::MessageDialog->new($self,
-							   [qw/modal destroy-with-parent/],
-							   'question',
-							   'cancel',
-							   $self->{lang}->{RemoveConfirm});
+        if ($self->{options}->confirm)
+        {
+            my  $dialog = Gtk2::MessageDialog->new($self,
+                                                   [qw/modal destroy-with-parent/],
+                                                   'question',
+                                                   'cancel',
+                                                   $self->{lang}->{RemoveConfirm});
 
             my $delButton = Gtk2::Button->new_from_stock('gtk-delete');
             $delButton->can_default(1);
@@ -122,17 +126,17 @@ use Gtk2;
             $dialog->vbox->pack_start($check,0,0,5);
             $dialog->vbox->pack_start(Gtk2::HSeparator->new,0,0,5);
             $dialog->vbox->show_all;
-		    $response = $dialog->run;
-		    $confirm = ($check->get_active ? 0 : 1);
-		    $dialog->destroy;
-		}
+            $response = $dialog->run;
+            $confirm = ($check->get_active ? 0 : 1);
+            $dialog->destroy;
+        }
 	
-		if ($response eq 'yes')
-		{
+        if ($response eq 'yes')
+        {
             $self->markAsUpdated;
             $self->{items}->removeCurrentItem;
             $self->{options}->confirm($confirm);
-		}
+        }
     }
 
     sub newItem
@@ -140,7 +144,7 @@ use Gtk2;
 			
         my ($self, $self2) = @_;
         $self = $self2 if $self2;
-		
+
         #$self->{options}->lockPanel(0);
         # Uncomment to memorize
         #$self->{panel}->changeState($self->{panel}, 0);
@@ -195,7 +199,7 @@ use Gtk2;
     
     sub searchItemForPanel
     {
-        my ($self, $panel) = @_;
+        my ($self, $panel, $forceSelection) = @_;
     
         if ($panel)
         {
@@ -209,7 +213,7 @@ use Gtk2;
             $query = $self->{panel}->getValue($_);
             ($field = $_, last) if ($query);
         }
-        $self->searchItem($query, 0, 0, $field);
+        $self->searchItem($query, $forceSelection, 0, $field);
         $self->{panel} = $self->{previousPanel} if ($panel);
     }
     
@@ -483,11 +487,38 @@ use Gtk2;
         }
     }
     
+    sub getImagesDir
+    {
+        my $self = shift;
+
+        #my $imagesDir = shift; 
+        my $imagesDir ||= $self->{items}->{information}->{images};
+        #We use the global one if none exists in the collection
+        $imagesDir ||= $self->{options}->images;
+        # TODO : We should have an error somewhere if WORKING_DIR is not on the beginning
+        if ($self->{options}->file)
+        {
+            $imagesDir =~ s/^(%WORKING_DIR%|\.)/dirname($self->{options}->file)/e;
+            $imagesDir =~ s/%FILE_BASE%/basename($self->{options}->file,  '.gcs')/e;
+        }
+        else
+        {
+            # If value contains one of the variables and we don't have a directory name
+            # we store everything in the temporary directory
+            $imagesDir = $self->{tmpImageDir}
+                if ($imagesDir =~ m/^(%WORKING_DIR%|\.)/)
+                || ($imagesDir =~ m/%FILE_BASE%/);
+        }
+        
+        return GCUtils::pathToUnix($imagesDir);
+    }
+
     sub getUniqueImageFileName
     {
         my ($self, $suffix, $itemTitle, $imagesDir) = @_;
-    
-        $imagesDir ||= $self->{options}->images;
+        
+        # If none specified, we use the default one
+        $imagesDir ||= $self->getImagesDir;
         $imagesDir =~ s+([^/])$+$1/+;
         my $imagePrefix;
         if ($self->{options}->useTitleForPics)
@@ -616,6 +647,8 @@ use Gtk2;
     {
         my ($self, $pictureUrl, $title) = @_;
     
+        $title ||= $self->{panel}->getValue($self->{model}->{commonFields}->{title});
+
         my ($name,$path,$suffix) = fileparse($pictureUrl, "\.gif", "\.jpg", "\.jpeg", "\.png");
         my $picture = $self->getUniqueImageFileName($suffix, $title);
 
@@ -697,10 +730,11 @@ use Gtk2;
 
         $self->initProgress($self->{lang}->{StatusLoad});
         $self->{openingFile} = 1;
+        my $previousFile = $self->{options}->file;
+        $self->setFile($filename);
         if ($self->{items}->load($filename, $self, 1))
         {
             $self->addFileHistory($filename);
-            $self->setFile($filename);
             $self->{options}->save;
             $self->selectFirst;
             $self->setTitle(basename($filename), $self->{items}->{information}->{name});
@@ -716,6 +750,7 @@ use Gtk2;
             $dialog->set_position('center-on-parent');
             $dialog->run();
             $dialog->destroy ;
+            $self->setFile($previousFile);
         }
         $self->{openingFile} = 0;
     }
@@ -785,17 +820,26 @@ use Gtk2;
             
         while (1)
         {
-    	   	my $response = $fileDialog->run;
+            my $response = $fileDialog->run;
             if ($response eq 'ok')
             {
                 my $filename = $fileDialog->get_filename;
                 $self->addFileHistory($filename);
                 my $previousFile = $self->{options}->file;
+                my $prevImages = $self->getImagesDir;
                 $self->setFile($filename);
-                if ($self->saveList())
+                # We re-generate it because it could have changed with new file name
+                my $newImages = $self->getImagesDir;
+                if ($prevImages ne $newImages)
+                {
+                    # The last 1 means we want copy, not move
+                    $self->{items}->setNewImagesDirectory($newImages, $prevImages, 1);
+                }
+                if ($self->{items}->save($self))
                 {
                     $self->{options}->save;
                     $self->setTitle(basename($filename), $self->{items}->{information}->{name});
+
                     last;
                 }
                 else
@@ -860,16 +904,16 @@ use Gtk2;
         }
         else
         {
-	       my $dialog = Gtk2::MessageDialog->new($self,
+            my $dialog = Gtk2::MessageDialog->new($self,
                                                   [qw/modal destroy-with-parent/],
                                                   'info',
                                                   'ok-cancel',
                                                   $self->{lang}->{SaveCurrentList});
 
-           $dialog->set_position('center-on-parent');
-	       $response = $dialog->run();
-	       $dialog->destroy ;
-		   $self->saveAs if ($response eq 'ok');
+            $dialog->set_position('center-on-parent');
+            $response = $dialog->run();
+            $dialog->destroy ;
+            $self->saveAs if ($response eq 'ok');
         }
     }
 
@@ -1000,11 +1044,11 @@ use Gtk2;
     {
         my ($self, $withDialog) = @_;
         my $error = 0;
-        if ( ! -e $self->{options}->images)
+        my $imagesDir = $self->getImagesDir;
+        if ( ! -e $imagesDir)
         {
-            $! = '';
-            mkdir($self->{options}->images);
-            $error = 1 if $!;
+            mkpath $imagesDir;
+            $error = 1 if ! -e $imagesDir;
         }
         else
         {
@@ -1022,7 +1066,7 @@ use Gtk2;
 						   $self->{lang}->{ImageError});
 
             $errorDialog->set_position('center-on-parent');
-            $fileDialog->set_filename($self->{options}->images);
+            $fileDialog->set_filename($imagesDir);
             my $response;
             do
             {
@@ -1065,6 +1109,10 @@ use Gtk2;
     {
         my $self = shift;
         
+#        my $prevImages = $self->{items}->{information}->{images}
+#                      || $self->{options}->images;
+        my $prevImages = $self->getImagesDir;
+
         my $dialog = $self->getDialog('Properties');
         $dialog->setProperties($self->{items}->{information},
                                $self->{options}->file,
@@ -1073,6 +1121,14 @@ use Gtk2;
         {
             $self->{items}->{information} = $dialog->getProperties;
             $self->setTitle(basename($self->{options}->file), $self->{items}->{information}->{name});
+            # We check if it has changed
+            my $newImages = $self->getImagesDir;
+            if ($prevImages ne $newImages)
+            {
+                # Here we want to move pictures
+                $self->{items}->setNewImagesDirectory($newImages, $prevImages, 0);
+            }
+            #$self->moveImages($prevImages, $self->{items}->{information}->{images});
             $self->markAsUpdated;
         }
     }
@@ -1103,17 +1159,17 @@ use Gtk2;
 
     sub setWaitCursor
     {
-		my ($self, $message) = @_;
+        my ($self, $message) = @_;
         $self->setStatus($message);
-		$self->window->set_cursor(Gtk2::Gdk::Cursor->new('watch'));
-		Gtk2->main_iteration while (Gtk2->events_pending);
+        $self->window->set_cursor(Gtk2::Gdk::Cursor->new('watch'));
+        Gtk2->main_iteration while (Gtk2->events_pending);
     }
     sub restoreCursor
     {
-		my $self = shift;
+        my $self = shift;
         $self->restoreStatus;
-		$self->window->set_cursor(Gtk2::Gdk::Cursor->new('left_ptr'));
-		Gtk2->main_iteration while (Gtk2->events_pending);
+        $self->window->set_cursor(Gtk2::Gdk::Cursor->new('left_ptr'));
+        Gtk2->main_iteration while (Gtk2->events_pending);
     }
 
     sub setFilter
@@ -1407,7 +1463,7 @@ use Gtk2;
         my ($self, $self2) = @_;
         $self = $self2 if $self2;
 
-        $self->launch('http://www.gcstar.org/doc', 'url');
+        $self->launch('http://wiki.gcstar.org/', 'url');
     }
 
     sub reportBug
@@ -1422,7 +1478,7 @@ use Gtk2;
         
         my $id = $topicIds{$self->{options}->lang} || $topicIds{EN};
         #$self->launch('https://gna.org/bugs/?func=additem&group=gcstar', 'url');
-        $self->launch('http://forums.gcstar.org/post.php?fid='.$id, 'url');
+        $self->launch('http://forums.gcstar.org/viewforum.php?id='.$id, 'url');
     }
 
     sub playItem
@@ -1438,6 +1494,7 @@ use Gtk2;
         my ($self, $file, $format, $withParams) = @_;
         
         $format ||= 'program';
+        my $command;
         # For image, we have an internal viewer
         if ($format eq 'image')
         {
@@ -1448,15 +1505,9 @@ use Gtk2;
             $self->{itemWindow}->showMe if $self->{itemWindow};
             return;
         }
-        
-        # For the other ones, we use external programs
-        my $command;
-        $command = $self->{options}->browser if $format eq 'url';
-        $command = $self->{options}->player if $format eq 'video';
-        $command = $self->{options}->audio if $format eq 'audio';
-        if ($^O =~ /win32/i)
+        elsif ($format eq 'program')
         {
-            if ($format eq 'program')
+           if ($^O =~ /win32/i)
             {
                 if ($withParams)
                 {
@@ -1470,24 +1521,48 @@ use Gtk2;
             }
             else
             {
-                $command = '"'.$command.'"';
-                $file =~ s/([^\\])"/$1\\"/g;
-                $command .= ' "'.$file.'"';
+                $command = $file;
             }
-            system "start \"\" $command";
         }
         else
         {
-            if ($format ne 'program')
+            # For the other ones, we use external programs
+            if ($self->{options}->programs eq 'system')
+            {
+                $command = ($^O =~ /win32/i) ? ''
+                         : ($^O =~ /macos/i) ? '/usr/bin/open'
+                         :                     $ENV{GCS_SHARE_DIR}.'/helpers/xdg-open';
+            }
+            else
+            {
+                $command = $self->{options}->browser if $format eq 'url';
+                $command = $self->{options}->player if $format eq 'video';
+                $command = $self->{options}->audio if $format eq 'audio';
+            }
+
+            if ($^O =~ /win32/i)
+            {
+                $command = '"'.$command.'"' if $command;
+                $file =~ s/([^\\])"/$1\\"/g;
+                $command .= ' "'.$file.'"';
+            }
+            else
             {
                 $file =~ s/([^\\])"/$1\\"/g;
                 #"
                 $command .= ' "'.$file.'"';
             }
-            else
-            {
-                $command = $file;
-            }
+
+        }
+        
+        # Finalize the command line
+        if ($^O =~ /win32/i)
+        {
+            #It looks like it only works with backquotes and not with system on win32 systems
+            `start \"\" $command`;
+        }
+        else
+        {
             system "$command &";
         }
     }
@@ -1514,8 +1589,8 @@ use Gtk2;
 
     sub setStatus
     {
-		my ($self, $status) = @_;
-		$self->{status}->push(1, $status) if ($self->{status});
+        my ($self, $status) = @_;
+        $self->{status}->push(1, $status) if ($self->{status});
     }
     
     sub restoreStatus
@@ -1563,11 +1638,8 @@ use Gtk2;
 
         if (!$random && ($code eq 'ok'))
         {
-            my $previous = $self->{panel}->getAsHash;
-            my $new = $window->{panel}->getAsHash;
             $self->{items}->updateCurrentFromPanel($window->{panel});
             $self->{items}->displayInPanel($self->{panel}, $idx);
-            $self->{itemsList}->changeCurrent($previous, $new);
             #Init combo boxes
             foreach(@{$self->{model}->{fieldsHistory}})
             {
@@ -1701,6 +1773,14 @@ use Gtk2;
         }
     }
     
+    sub setSensitive
+    {
+        my ($self, $sensitive) = @_;
+        $self->{menubar}->set_sensitive($sensitive);
+        $self->{toolbar}->set_sensitive($sensitive);
+        $self->{pane}->set_sensitive($sensitive);
+    }
+    
     sub initProgress
     {
         my ($self, $label) = @_;
@@ -1711,9 +1791,7 @@ use Gtk2;
         }
         return if $self->{openingFile};
         $self->setProgress(0.0);
-        $self->{menubar}->set_sensitive(0);
-        $self->{toolbar}->set_sensitive(0);
-        $self->{pane}->set_sensitive(0);
+        $self->setSensitive(0);
     }
     
     sub endProgress
@@ -1729,9 +1807,7 @@ use Gtk2;
             $self->setProgress(0.0);
             return 0;
         });
-        $self->{menubar}->set_sensitive(1);
-        $self->{toolbar}->set_sensitive(1);
-        $self->{pane}->set_sensitive(1);
+        $self->setSensitive(1);
     }
     
     sub setProgress
@@ -2028,6 +2104,8 @@ use Gtk2;
             my @pics = glob($self->{pluginsPicturesDir}.'/*.png');
             $self->{hasPluginsPictures} = 1 if $#pics > 0;
         }
+        $self->{tmpImageDir} = tempdir(CLEANUP => 1);
+
         $self->{lang} = $GCLang::langs{$self->{options}->lang};
 
         GCPlugins::loadPlugins;
@@ -2052,7 +2130,6 @@ use Gtk2;
         $self->{style} = $style;
         
         $self->{initializing} = 1;
-        $self->set_sensitive(0);
 
         if (($self->{options}->splash) || (! $self->{options}->exists('splash')))
         {
@@ -2064,7 +2141,7 @@ use Gtk2;
             $self->loadPrevious;
             $self->initEnd;
             $self->{initializing} = 0;
-            $self->set_sensitive(1);
+            $self->setSensitive(1);
         }
 
         return $self;
@@ -2169,8 +2246,6 @@ use Gtk2;
         $self->signal_connect(delete_event => \&beforeDestroy, $self);
         $self->signal_connect(destroy => sub { Gtk2->main_quit; });
         
-        #$splash->setProgress(0.02) if $splash;
-        
         $self->createContextMenu;
 
         $splash->setProgress(0.03) if $splash;
@@ -2182,8 +2257,6 @@ use Gtk2;
         $self->{menubar}->set_name('GCMenubar');
         $self->{bookmarksLoader} = new GCBookmarksLoader($self, $self->{menubar});
 
-        #$splash->setProgress(0.04) if $splash;
-
         $self->{toolbar} = GCToolBar->new($self);
         $self->{handleToolbar} = new Gtk2::HandleBox;
         
@@ -2219,15 +2292,13 @@ use Gtk2;
         $self->{status}->pack_start($self->{progress}, 0, 0, 5);
         $self->{mainVbox}->pack_start($self->{status},0,0,0);
 
+        $self->setSensitive(0);
         $self->checkToolbarPosition;
-
         $self->add($self->{mainVbox});
 
         $splash->setProgress(0.05) if $splash;
 
         $self->set_default_size($self->{options}->width,$self->{options}->height);
-       
-        #$splash->setProgress(0.06) if $splash;
 
         $self->drag_dest_set('all', ['copy','private','default','move','link','ask']);
 
@@ -2301,8 +2372,6 @@ use Gtk2;
         # Workaround for a Gtk2 bug. Field selector is not shown again when hidden.
         $self->{toolbar}->setShowFieldsSelection($self->{options}->toolbarPosition <= 1);
 
-        #$splash->setProgress(0.08) if $splash;
-
         $self->checkDisplayed;
 
         $self->checkView;
@@ -2557,6 +2626,7 @@ use Gtk2;
     {
         my $self = shift;
         my $splash = shift;
+
         if (! $self->{items}->setOptions($self->{options}, $splash))
         {
             $self->setTitle('');
