@@ -2,7 +2,7 @@ package GCMenu;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -862,7 +862,7 @@ use strict;
 
         $self->{groupLabel} = new Gtk2::Label($self->{lang}->{ToolbarGroupBy});
         $self->append_widget($self->{groupLabel}, undef, undef);
-        $self->{groupOption} = new GCFieldSelector;
+        $self->{groupOption} = new GCFieldSelector(0, undef, 1);
         $self->{groupOption}->set_focus_on_click(0);
         $self->{groupOption}->signal_connect('changed' => sub {
             return if $self->{blocked};
