@@ -2,7 +2,7 @@ package GCModel;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -54,6 +54,7 @@ our $initDefault = 'DefaultNewItem';
         my $self = shift;
         my $xs = XML::Simple->new;
         return if ! $self->{xmlString};
+        
         $self->{collection} = $xs->XMLin($self->{xmlString},
                                          ForceArray => ['item', 'values', 'filter', 'panel', 'group', 'field'],
                                          KeyAttr => {'group' => '',
@@ -271,6 +272,7 @@ our $initDefault = 'DefaultNewItem';
         my %fieldsInfo;
         my @fieldsHistory;
         my @fieldsNotNull;
+        my @fieldsNotFormatted;
         my @fieldsImage;
         my @managedImages;
         my $name;
@@ -293,11 +295,14 @@ our $initDefault = 'DefaultNewItem';
             }
             push @fieldsNotNull, $name
                 if $_->{notnull} eq 'true';
+            push @fieldsNotFormatted, $name
+                if $_->{type} ne 'formatted';
         }
         $self->{fieldsNames} = \@fieldsNames;
         $self->{fieldsInfo} = \%fieldsInfo;
         $self->{fieldsHistory} = \@fieldsHistory;
         $self->{fieldsNotNull} = \@fieldsNotNull;
+        $self->{fieldsNotFormatted} = \@fieldsNotFormatted;
         $self->{managedImages} = \@managedImages;
         $self->{fieldsImage} = \@fieldsImage;
     }
@@ -928,8 +933,15 @@ our $initDefault = 'DefaultNewItem';
     {
         my $self = shift;
         my $info = {};
-        $info->{$_} = $self->getDisplayedText($self->{fieldsInfo}->{$_}->{init})
-            foreach (@{$self->{fieldsNames}});
+        foreach my $field (@{$self->{fieldsNames}})
+        {
+            $info->{$field} = $self->getDisplayedText($self->{fieldsInfo}->{$field}->{init});
+            if ($self->{fieldsInfo}->{$field}->{type} eq 'formatted')
+            {
+                $info->{$field} =~ s/%(.*?)%//g;
+            }
+            #foreach (@{$self->{fieldsNames}});
+        }
         return $info;
     }
 
@@ -1359,6 +1371,8 @@ use Gtk2;
                 $_->{value} =~ /([0-9]+)$/;
                 $self->{maxId} = $1 if $self->{maxId} < $1;
                 $self->{idToLabel}->{$_->{value}} = $_->{label};
+                $_->{init} = $self->convertFormat($_->{init}, 1)
+                    if $_->{type} eq 'formatted';
             }
             $self->displayField(0) if scalar(@{$self->{fields}});
         }
@@ -1366,6 +1380,45 @@ use Gtk2;
         $self->{hasLending}->setValue($withLending);
     }
 
+    sub convertFormat
+    {
+        my ($self, $format, $toUser) = @_;
+        my $converted = $format;
+        if ($toUser)
+        {
+            $converted =~ s/%(.*?)%/'%'.$self->idToLabel($1).'%'/ge;
+        }
+        else
+        {
+            $converted =~ s/%(.*?)%/'%'.$self->labelToId($1).'%'/ge;
+        }
+        # If some replacements failed, we clean the string
+        $converted =~ s/%%//g;
+        return $converted;
+    }
+
+    sub idToLabel
+    {
+        my ($self, $id) = @_;
+        for my $field (@{$self->{fields}})
+        {
+            return $field->{label}
+                if $field->{value} eq $id;
+        }
+        return '';
+    }
+
+    sub labelToId
+    {
+        my ($self, $label) = @_;
+        for my $field (@{$self->{fields}})
+        {
+            return $field->{value}
+                if $field->{label} eq $label;
+        }
+        return '';
+    }
+
     sub initFilters
     {
         my ($self, $filters) = @_;
@@ -1435,6 +1488,15 @@ use Gtk2;
         $self->saveCurrent;
         $self->saveCurrentFilter;
         $self->hide;
+        if ($response eq 'ok')
+        {
+            # Restore formats
+            foreach my $field(@{$self->{fields}})
+            {
+                $field->{init} = $self->convertFormat($field->{init}, 0)
+                    if $field->{type} eq 'formatted';
+            }
+        }
         return ($response eq 'ok');
     }
 
@@ -1900,6 +1962,7 @@ use Gtk2;
                                     {value => 'image', displayed => $parent->{lang}->{ModelFieldTypeImage}},
                                     {value => 'single list', displayed => $parent->{lang}->{ModelFieldTypeSingleList}},
                                     {value => 'file', displayed => $parent->{lang}->{ModelFieldTypeFile}},
+                                    {value => 'formatted', displayed => $parent->{lang}->{ModelFieldTypeFormatted}},
                                  ]);
         $self->{params}->{type}->signal_connect('changed' => sub {
             $self->checkFieldType;
@@ -2069,9 +2132,9 @@ use Gtk2;
         
 
 
-        $notebook->append_page($vboxFields, 'Fields');
-        $notebook->append_page($vboxOptions, 'Options');
-        $notebook->append_page($vboxFilters, 'Filters');
+        $notebook->append_page($vboxFields, $parent->{lang}->{ModelFields});
+        $notebook->append_page($vboxOptions, $parent->{lang}->{ModelOptions});
+        $notebook->append_page($vboxFilters, $parent->{lang}->{ModelFilters});
 
         $self->vbox->pack_start($hboxCollectionName, 0, 0, $GCUtils::margin);
         $self->vbox->pack_start($notebook, 1, 1, 0);
