@@ -2,7 +2,7 @@ package GCPanel;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -259,15 +259,15 @@ use strict;
 
     sub dataChanged
     {
-        my $self = shift;
-        
+        my ($self, $info) = @_;
+
         foreach (@{$self->{expanders}})
         {
             $self->setExpanderLabel($_, 1);
         }
         foreach (@{$self->{formatted}})
         {
-            $self->setFormattedLabel($_, 1);
+            $self->setFormattedLabel($_, 1, $info);
         }
     }
 
@@ -307,12 +307,27 @@ use strict;
         }
     }
     
+    sub setAsFormatted
+    {
+        my ($self, $widget, $name, $format) = @_;
+        $widget->{format} = $format;
+        $widget->{name} = $name;
+        push @{$self->{formatted}}, $widget;
+        while ($format =~ /%(.*?)%/g)
+        {
+            push @{$self->{dependencies}->{$1}}, $widget;
+        }
+    }
+
     sub setFormattedLabel
     {
-        my ($self, $label, $init) = @_;
+        my ($self, $label, $init, $info) = @_;
 
         my $name = $label->{name};
         $self->$name($self->formatLabel($label->{format}));
+        # We store here the value so it could be used by caller if needed
+        # The user is GCData::updateCurrent
+        $info->{$name} = $self->$name if defined $info;
     }
 
     sub addToContainer
@@ -339,10 +354,20 @@ use strict;
                 $hbox->pack_start($widget,0,0,0);
                 $widget = $hbox;
             }
-            $container->attach($widget,
-                               $left, $right, $top, $bottom,
-                               $fill, $fill,
-                               0, 0);
+            if ($info->{expand} eq 'horizontal')
+            {
+                $container->attach($widget,
+                                   $left, $right, $top, $bottom,
+                                   ['expand', 'fill'], [],
+                                   0, 0);
+            }
+            else
+            {
+                $container->attach($widget,
+                                   $left, $right, $top, $bottom,
+                                   $fill, $fill,
+                                   0, 0);
+            }
         }
         else
         {
@@ -399,14 +424,8 @@ use strict;
                 $info->{type} = 'short text';
                 $info->{value} = $_->{name};
                 $widget = $self->createItem($info);
-                $widget->{format} = $_->{value};
-                $widget->{name} = $_->{name};
                 $self->{$_->{name}} = $widget;
-                push @{$self->{formatted}}, $widget;
-                while ($_->{value} =~ /%(.*?)%/g)
-                {
-                    push @{$self->{dependencies}->{$1}}, $widget;
-                }
+                $self->setAsFormatted($widget, $_->{name}, $_->{value});
                 $_->{for} = $widget->{name};
             }
             elsif ($_->{type} eq 'value')
@@ -415,7 +434,12 @@ use strict;
                 $widget->setWidth($_->{width}) if $_->{width};
                 $widget->setHeight($_->{height}) if $_->{height};
                 $widget->expand if $_->{expand} eq 'true';
-                $self->{displayedValues}->{$_->{for}} = $_->{values} if $_->{values};
+                if ($_->{values} || $self->{model}->{fieldsInfo}->{$_->{for}}->{values})
+                {
+                    $self->{displayedValues}->{$_->{for}} = 
+                            $_->{values}
+                         || $self->{model}->{fieldsInfo}->{$_->{for}}->{values};
+                }
             }
             elsif ($_->{type} eq 'label')
             {
@@ -710,7 +734,6 @@ use strict;
         my $label = $self->{model}->getDisplayedText($info->{label});
         my $widget = new GCColorLabel($self->{styles}->{label}->{bgColor});
         $widget->set_selectable(0);
-        $widget->set_alignment(0,0.5);
         $widget->set_padding(5,5);
         $widget->set_justify('fill');
         $widget->set_markup("<span ".$self->{styles}->{label}->{style}.">".$label.'</span>');
@@ -766,6 +789,12 @@ use strict;
                                        $self->{styles}->{field},
                                        $self->{model}->getDisplayedText($info->{label}));            
         }
+        elsif ($info->{type} eq 'url')
+        {
+            $widget = new GCColorLink($self->{styles}->{field}->{bgColor}, $self->{parent});
+            $self->{style}->{$info->{value}} = 'field';
+            $widget->set_selectable(0);
+        }
         else
         {
             # See GCColorLabel constructor for the meaning of listType;
@@ -774,11 +803,12 @@ use strict;
                 $self->{prepare}->{$info->{value}}->{func} = 'prepareBorrower';
             }
             $widget = new GCColorLabel($self->{styles}->{field}->{bgColor});
-            $widget->set_alignment(0,0.5);
             $self->{style}->{$info->{value}} = 'field';
             $widget->set_selectable(0);
             $widget->set_padding(5,5);
             $widget->set_justify('fill');
+            $self->setAsFormatted($widget, $info->{value}, $info->{init})
+                if ($info->{type} eq 'formatted');
         }
         $widget->{name} = $info->{value};        
         return $widget;
@@ -805,7 +835,6 @@ use strict;
             $self->{prepare}->{$field}->{func} = 'prepareMultipleList';
             $self->{prepare}->{$field}->{extra} = $columns;
             $widget = new GCColorLabel($self->{styles}->{field}->{bgColor}, $columns);
-            $widget->set_alignment(0,0.5);
             $self->{style}->{$field} = 'field';
             $widget->set_selectable(0);
             $widget->set_padding(5,5);
@@ -893,9 +922,13 @@ use strict;
         push @{$self->{toDestroy}}, $self->{mailButton};
 
         $self->{searchButton} = GCButton->newFromStock('gtk-jump-to');
-        $self->{searchButton}->signal_connect('clicked' => sub {
+        $self->{searchButton}->signal_connect('activate' => sub {
             $self->searchItem;
         });
+        $self->{searchButton}->signal_connect('button_release_event' => sub {
+            my ($widget, $event) = @_;
+            $self->searchItem($event->button == 3);
+        });
         $self->{tooltips}->set_tip($self->{searchButton}, $self->{parent}->{lang}->{PanelSearchTip}, '');
         push @{$self->{toDestroy}}, $self->{searchButton};
         
@@ -946,10 +979,10 @@ use strict;
 
     sub searchItem
     {
-        my $self = shift;
+        my ($self, $forceSelection) = @_;
 
         #$self->{parent}->searchItemForPanel($self->{$self->{model}->{commonFields}->{title}}->getValue, $self);
-        $self->{parent}->searchItemForPanel($self);
+        $self->{parent}->searchItemForPanel($self, $forceSelection);
 
         $self->showMe;
     }
@@ -1129,7 +1162,7 @@ use strict;
                 if $info->{history} eq 'false';
             $readonly = 1
                 if $info->{value} eq $self->{model}->{commonFields}->{borrower}->{history};
-            my $number = GCUtils::listNameToNumber($info->{type});
+            $number = GCUtils::listNameToNumber($info->{type});
             if ($number == 1)
             {
                 @labels = ($self->{model}->getDisplayedText($info->{label}));
@@ -1177,12 +1210,19 @@ use strict;
         }
         elsif ($info->{type} eq 'button')
         {
-            $widget = new GCButton($self->{model}->getDisplayedText($info->{label}));
+            if ($info->{format} eq 'url')
+            {
+                $widget = new GCUrlButton($self->{model}->getDisplayedText($info->{label}),
+                                          $self->{parent});
+            }
+            else
+            {
+                $widget = new GCButton($self->{model}->getDisplayedText($info->{label}));
+            }
         }
         elsif ($info->{type} eq 'url')
         {
-            $widget = new GCUrlButton($self->{model}->getDisplayedText($info->{label}),
-                                      $self->{parent});
+            $widget = new GCUrl($self->{parent});
         }
         elsif ($info->{type} eq 'yesno')
         {
@@ -1196,12 +1236,21 @@ use strict;
         {
             $widget = new GCDate($self, $self->{lang});
         }
+        elsif ($info->{type} eq 'formatted')
+        {
+            $widget = new GCShortText;
+            $widget->setReadOnly;
+            $self->setAsFormatted($widget, $info->{value}, $info->{init});
+        }
         else
         {
             print "Invalid type : ",$info->{type}," for ",$info->{value},"\n";
             $widget = 0;
         }
         
+         $self->{tooltips}->set_tip($widget, $self->{model}->getDisplayedText($info->{tip}), '')
+            if $info->{tip};
+        
         return $widget;
     }
     
