@@ -3,7 +3,7 @@
     
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -627,9 +627,10 @@ sub loadPlugins
         $self->show_all;
         $self->{nextButton}->hide if !$self->{withNext};
         my $ended = 0;
+        my $code;
         while (!$ended)
         {
-            my $code = $self->run;
+            $code = $self->run;
             if ($code eq 'ok')
             {
                 $self->{validated} = 1;
@@ -644,6 +645,7 @@ sub loadPlugins
             }
             $ended = 1 if ($code eq 'ok') || ($code eq 'cancel') || ($code eq 'delete-event');
         }
+        $self->hideTooltip;
         $self->hide;
         return ($code eq 'no');
     }
@@ -714,6 +716,18 @@ sub loadPlugins
         $self->{scrollPanelList}->set_shadow_type('etched-in');
                                             
         $self->vbox->add($self->{scrollPanelList});
+        
+        # To create a tooltip as it is not implemented directly in Gtk2
+        $self->{tooltipLabel} = Gtk2::Label->new;
+        $self->{tooltipLabel}->set_line_wrap(1);
+        $self->{tooltipLabel}->set_padding($GCUtils::margin, $GCUtils::margin);
+        $self->{tooltip} = Gtk2::Window->new('popup');
+        $self->{tooltip}->set_decorated(0);
+        $self->{tooltip}->modify_fg('normal', Gtk2::Gdk::Color->parse('#000000'));
+        $self->{tooltip}->modify_bg('normal', Gtk2::Gdk::Color->parse('#ffffbf'));
+        $self->{tooltip}->set_position('mouse');
+        $self->{tooltip}->add($self->{tooltipLabel});
+        $self->{tooltipDisplayed} = 0;        
  
         return $self;
     }
@@ -745,7 +759,8 @@ sub loadPlugins
         $self->{nbCols} = scalar @{$self->{fields}};
         
         $self->{results} = Gtk2::SimpleList->new(@cols);
-
+        
+        
         $self->{results}->set_rules_hint(1);
         $self->{results}->set_headers_clickable(1);
 
@@ -759,6 +774,7 @@ sub loadPlugins
             $self->{results}->get_column($i)->signal_connect('clicked' => sub {
                 $self->sort($self->{fields}->[$i]);
             });
+            $self->{results}->get_column($i)->{column_number} = $i;
         }
          
        $self->{scrollPanelList}->add($self->{results});
@@ -767,6 +783,15 @@ sub loadPlugins
             my ($sl, $path, $column) = @_;
             $self->response('ok');
         });
+        $self->{results}->signal_connect('motion-notify-event' => sub {
+            my ($widget, $event) = @_;
+            $self->displayTooltip($event);
+        });
+        $self->{results}->signal_connect('leave-notify-event' => sub {
+            my ($widget, $event) = @_;
+            # It corresponds to a leave of the whole widget not from a single cell
+            $self->hideTooltip if $event->detail eq 'ancestor';
+        });
 
     }
 
@@ -814,18 +839,26 @@ sub loadPlugins
         $self->{items} = \@items;
 
         @{$self->{results}->{data}} = ();
+        $self->{tooltipsStrings} = {};
 
         my $idx = 0;
+        my $col = 0;
         foreach my $item (@items)
         {
             my $infos = [];
+            $col = 0;
             foreach my $field(@{$self->{fields}})
             {
                 (my $shortField = $item->{$field}) =~ s/(.{40}).*/$1.../;
                 push @$infos, $shortField."\n";
+                # We store a tooltip is the text has been truncated
+                $self->{tooltipsStrings}->{$idx}->{$col} = $item->{$field}
+                    if $item->{$field} ne $shortField;
+                $col++;
             }
             $item->{'#'} = $idx if ! exists $item->{'#'};
             push @{$self->{results}->{data}}, $infos;
+            #push @{$self->{tooltipsStrings}}, $item->{$self->{fields}->[0]};
             $idx++;
         }
         $self->{results}->select(0);
@@ -833,7 +866,59 @@ sub loadPlugins
         #$self->resize(1,1);
         $self->set_default_size(200,400);
     }
+ 
+ 
+     sub displayTooltip 
+     {        
+        my ($self, $event) = @_;
+        my ($path, $column, $cell_x, $cell_y) = $self->{results}->get_path_at_pos ($event->x, $event->y);
+        if ($path)
+        {
+            my $model = $self->{results}->get_model;
+            use Data::Dumper;
+            my $i = $column->{column_number};
+            my $row = $path->to_string();
+            
+            # If a new cell is selected, then hide the tooltip
+            # It'll be re-shown as required by the code down under
+            if ($self->{selectedRow} ne $row or $self->{selectedCol} != $i)
+            {
+                $self->hideTooltip;
+                $self->{selectedRow} = $row;
+                $self->{selectedCol} = $i;
+            }
+            if ($row ne '')
+            {
+                # Pick that popup string from our hash
+                #my $str = $popup_hash->{$row}->{$i};
+                my $str = $self->{tooltipsStrings}->{$row}->{$i};
+                if ($str)
+                {
+                    $self->{tooltipLabel}->set_label($str);
+                    if (!$self->{tooltipDisplayed})
+                    {
+                        $self->{tooltip}->show_all;
+                        my ($thisx, $thisy) = $self->{tooltip}->window->get_origin;
+                        # The window to be a bit away from the mouse pointer.
+                        $self->{tooltip}->move($thisx, $thisy-20);
+                        $self->{tooltipDisplayed} = 1;
+                    } 
+                } 
+            }
+            return 0;
+        }
+    }
     
+    sub hideTooltip
+    {
+        my $self = shift;
+        if ($self->{tooltipDisplayed})
+        {
+            $self->{tooltip}->hide;
+            $self->{tooltipDisplayed} = 0;
+        }
+     }
+   
 }
 
 {
