@@ -2,7 +2,7 @@ package GCPlugins::GCPluginsBase;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -183,7 +183,8 @@ use utf8;
         else
         {
             eval {
-                $result = decode($self->getCharset, $result);
+                $result = decode($self->getCharset, $result)
+                    unless $self->getCharset eq 'UTF-8';
             };
         }
 
@@ -201,6 +202,9 @@ use utf8;
     {
         my $self = shift;
 
+        eval {
+            $self->init;
+        };
         my $idx = $self->{wantedIdx};
         my $url = $self->getItemUrl($self->{itemsList}[$idx]->{url});
         $self->loadUrl($url);
@@ -218,7 +222,6 @@ use utf8;
     sub loadUrl
     {
         my ($self, $url) = @_;
-        
         $self->checkProxy;
         
         my $realUrl = $self->changeUrl($url);
@@ -246,7 +249,7 @@ use utf8;
             {
                 $self->{curInfo}->{$_} =~ s/\|/,/gm;
                 $self->{curInfo}->{$_} =~ s/\r//gm;
-                $self->{curInfo}->{$_} =~ s/\s*$//gm;
+                $self->{curInfo}->{$_} =~ s/[ \t]*$//gm;
             }
         }
         
