@@ -2,7 +2,7 @@ package GCPlugins::GCbooks::GCAmazon;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -181,10 +181,16 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                 $self->{curInfo}->{language} = $origtext;
                 $self->{insideLanguage} = 0;
             }
-            elsif ($self->{insideIsbn})
+            elsif ($self->{insideIsbn10})
+            {
+                $self->{curInfo}->{isbn} = $origtext unless $self->{haveIsbn13};
+                $self->{insideIsbn10} = 0;
+            }
+            elsif ($self->{insideIsbn13})
             {
                 $self->{curInfo}->{isbn} = $origtext;
-                $self->{insideIsbn} = 0;
+                $self->{insideIsbn13} = 0;
+                $self->{haveIsbn13} = 1;
             }
             elsif ($self->{insidePages})
             {
@@ -194,10 +200,11 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             elsif ($self->{inside}->{b})
             {
                 $self->{insideDesc} = 1 if $origtext eq 'Book Description' 
-                                        || $origtext =~ /^Amazon.com/;
+                                        || $origtext =~ /^Amazon.com(?! Sales)/;
                 $self->{insidePublisher} = 1 if $origtext =~ /Publisher:/;
 				$self->{insideLanguage} = 1 if $origtext =~ /Language:/;
-				$self->{insideIsbn} = 1 if $origtext =~ /ISBN:/;
+                $self->{insideIsbn10} = 1 if $origtext =~ /ISBN(-10)?:/;
+                $self->{insideIsbn13} = 1 if $origtext =~ /ISBN-13:/;
 				if ($self->{insideDetails})
                 {
                     $origtext =~ s/:$//;
@@ -277,7 +284,8 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $self->{insideLanguage} = 0;
             $self->{insideSerie} = 0;
             $self->{insidePages} = 0;
-            $self->{insideIsbn} = 0;
+            $self->{insideIsbn10} = 0;
+            $self->{insideIsbn13} = 0;
         }
         
         $self->{alreadyRetrieved} = {};
