@@ -2,7 +2,7 @@ package GCPlugins::GCbooks::GCAmazonDE;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -189,7 +189,7 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                                         || $origtext eq 'Aus der Amazon.de-Redaktion';
                 $self->{insidePublisher} = 1 if $origtext =~ /Verlag:/;
 				$self->{insideLanguage} = 1 if $origtext =~ /Sprache:/;
-				$self->{insideIsbn} = 1 if $origtext =~ /ISBN:/;
+				$self->{insideIsbn} = 1 if $origtext =~ /ISBN-13:/;
 				if ($self->{insideDetails})
                 {
                     $origtext =~ s/:$//;
@@ -259,6 +259,10 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 
         $html =~ s/&nbsp;/ /gi;
         $html =~ s/&#146;/'/gm;
+		$html =~ s/&#150;/-/gm;
+		$html =~ s/&#132;/&#187;/gm;
+		$html =~ s/&#147;/&#171;/gm;
+		HTML::Entities::decode_entities($html);
         $self->{parsingEnded} = 0;
         if ($self->{parsingList})
         {
