@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCAmazonDE;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -180,7 +180,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 				$self->{insideDirector} = 1 if $origtext =~ /Regisseur\(e\):/;
 				$self->{insideAge} = 1 if $origtext =~ /FSK:/;
 				$self->{insideTime} = 1 if $origtext =~ /Spieldauer:/;
-    			$self->{insideSynopsis} = 1 if $origtext =~ /VideoWoche/;
+    			$self->{insideSynopsis} = 1 if $origtext =~ /(VideoWoche|Amazon\.de|Movieman\.de|VideoWoche|VideoMarkt|Kurzbeschreibung)/;
 			}        
         }
     } 
