@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCFilmWeb;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -51,21 +51,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 }
             }
             
-            if (($tagname eq 'img')
-             && ($attr->{src} eq 'http://gfx.filmweb.pl/gf/ic/lu.gif')
-             && ($self->{insideResults} != -1))
-            {
-                $self->{insideResults} = 1;
-            }
-            
-            if (($tagname eq 'form')
-             && ($self->{insideResults} == 1))
-            {
-                $self->{insideResults} = -1;
-            }
-            
             if (($tagname eq 'a')
-             && ($self->{insideResults} == 1))
+             && ($attr->{class} eq 'searchResultTitle'))
             {
                 $self->{isMovie} = 1;
                 $self->{itemIdx}++;
@@ -92,9 +79,9 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 $self->{isCountry} = 1
                     if (! ($self->{curInfo}->{date} || $self->{curInfo}->{type}))
-                    && ($attr->{href} =~ m|/film/top/world\?country\.id=|);
+                    && ($attr->{href} =~ m|/film\?countryIds=|);
                 $self->{isGenre} = 1
-                    if ($attr->{href} =~ m|/film/top/world\?genre\.id=|);
+                    if ($attr->{href} =~ m|/film\?genreIds=|);
                 if ($attr->{href} =~ m|,FilmDescriptions,|)
                 {
                     my $page = $self->loadPage($attr->{href});
@@ -152,17 +139,26 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             if ($self->{isMovie})
             {
-                $origtext =~ s/^\s*//m;
-                $origtext =~ s/\s*$//m;
-                $origtext =~ s|\s*\([[:alpha:].]*\)$||;
-                return if !$origtext;
-                #$origtext =~ m|^([^/]*?)(/[^(]*)?.*?\(([0-9]{4})\)$|;
-                $origtext =~ m|(.*?)\(([0-9]{4})\)$|;
-                
-                $self->{itemsList}[$self->{itemIdx}]->{title} = $1;
-                $self->{itemsList}[$self->{itemIdx}]->{date} = $2;
                 $self->{isMovie} = 0;
+                if ($self->{inside}->{a})
+                {
+                    $origtext =~ s/^\s*//m;
+                    $origtext =~ s/\s*$//m;
+                    $origtext =~ s|\s*\([[:alpha:].]*\)$||;
+                    return if !$origtext;
+                    #$origtext =~ m|(.*?)\(([0-9]{4})\)$|;
+                
+                    $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                    #$self->{itemsList}[$self->{itemIdx}]->{date} = $2;
+                    $self->{isMovie} = 1;
+                }
+                else
+                {
+                    $self->{itemsList}[$self->{itemIdx}]->{date} = $1
+                        if $origtext =~ /\s*\(([0-9]{4})\)\s*/;
+                }
             }
+
         }
         else
         {
@@ -248,7 +244,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $self->{insideResults} = 0;
         $self->{actorsCounter} = 0;
 
-        if (!$self->{parsingList})
+        if ($self->{parsingList})
+        {
+            $html =~ s|<b>(.*?)</b>|$1|gms;
+        }
+        else
         {
             $html =~ s|<div style="margin: 0px 15px 5px 15px; font-family: Verdana, Geneva, Arial, Helvetica, sans-serif; font-size: 11px;">(.*?)</div>|<details>$1</details></div>|gms;
             #$html =~ s|<\!-- z backup -->(.*?)</div>|<details>$1</details></div>|gms;
@@ -266,7 +266,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
 		my ($self, $word) = @_;
 	
-        return "http://www.filmweb.pl/Find?query=$word&category=1&submit=szukaj";
+        return "http://www.filmweb.pl/szukaj?q=$word&c=film"
     }
     
     sub getItemUrl
