@@ -2,7 +2,7 @@ package GCPlugins::GCgames::GCJeuxVideoCom;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -107,6 +107,11 @@ use GCPlugins::GCgames::GCgamesCommon;
                     $self->{is} = 'editor';
                     $self->{isEditor} = 0;
             }
+            elsif ( ($tagname eq 'a') && ($self->{isDeveloper}) )
+            {
+                    $self->{is} = 'developer';
+                    $self->{isDeveloper} = 0;
+            }
             elsif ( ($tagname eq 'td') && ($self->{isGenre}) )
             {
                     $self->{is} = 'genre';
@@ -243,6 +248,7 @@ use GCPlugins::GCgames::GCgamesCommon;
             if ($self->{is})
             {
                 $origtext =~ s/^\s*//;
+                $origtext =~ s/\n$//;
                 
                 $self->{curInfo}->{$self->{is}} = $origtext;
                 $self->{is} = '';
@@ -252,6 +258,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                 $self->{isDate} = 1 if $origtext =~ /Sortie :/;
                 $self->{isGenre} = 1 if $origtext =~ /Type :/;
                 $self->{isEditor} = 1 if $origtext =~ /Editeur :/;
+                $self->{isDeveloper} = 1 if $origtext =~ /D.veloppeur :/;
                 $self->{isStrong} = 0;
             }
             elsif ($self->{isTest} eq '2')
@@ -310,6 +317,7 @@ use GCPlugins::GCgames::GCgamesCommon;
         $self->{isName} = 0;
         $self->{isGame} = 0;
         $self->{isEditor} = 0;
+        $self->{isDeveloper} = 0;
         $self->{isDate} = 0;
         $self->{isGenre} = 0;
         $self->{isBox} = 0;
@@ -337,7 +345,7 @@ use GCPlugins::GCgames::GCgamesCommon;
             $html =~ s|<img src="../pics/psx/croix.gif" />|croix|g;
             $html =~ s|<img src="../pics/psx/carre.gif" />|carre|g;
             $html =~ s|<img src="../pics/psx/triangle.gif" />|triangle|g;
-
+            $html =~ s|\x{92}|'|g;
         }
         return $html;
     }
@@ -353,7 +361,8 @@ use GCPlugins::GCgames::GCgamesCommon;
     {
 		my ($self, $url) = @_;
 		
-        return $url;
+        return $url unless $url eq '';
+        return 'http://www.jeuxvideo.com/';
     }
 
     sub getName
