@@ -2,7 +2,7 @@ package GCPlugins::GCgames::GCMobyGames;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -39,6 +39,10 @@ use GCPlugins::GCgames::GCgamesCommon;
         my $answer = "";
         my @tmpAnswer = ();
         my $html = $self->loadPage($html_ini);
+        $html =~ s|<pre>||g;
+        $html =~ s|</pre>||g;
+        $html =~ s|<b>||g;
+        $html =~ s|</b>||g;
         my $found = index($html,"class=\"sbL sbB sbT\">");
         if ( $found >= 0 )
         {
@@ -219,6 +223,11 @@ use GCPlugins::GCgames::GCgamesCommon;
                     $self->{is} = 'editor';
                     $self->{isEditor} = 0;
             }
+            elsif ( ($tagname eq 'a') && ($self->{isDeveloper}) )
+            {
+                    $self->{is} = 'developer';
+                    $self->{isDeveloper} = 0;
+            }
             elsif ( ($tagname eq 'a') && ($self->{isDate}) )
             {
                     $self->{is} = 'released';
@@ -420,6 +429,10 @@ use GCPlugins::GCgames::GCgamesCommon;
             {
                     $self->{curInfo}->{description} .= $origtext;
             }
+            elsif ($origtext eq 'Developed by')
+            {
+                $self->{isDeveloper} = 1
+            }
             elsif ($origtext eq 'Released')
             {
                 $self->{isDate} = 1
@@ -458,6 +471,7 @@ use GCPlugins::GCgames::GCgamesCommon;
         $self->{isGame} = 0;
         $self->{isPlatform} = 0;
         $self->{isEditor} = 0;
+        $self->{isDeveloper} = 0;
         $self->{isDate} = 0;
         $self->{isGenre} = 0;
         $self->{isDescription} = 0;
@@ -488,7 +502,8 @@ use GCPlugins::GCgames::GCgamesCommon;
     {
         my ($self, $url) = @_;
 		
-        return $url;
+        return $url unless $url eq '';
+        return 'http://www.mobygames.com/';
     }
 
     sub getName
