@@ -2,7 +2,7 @@ package GCSplash;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -121,7 +121,7 @@ use Gtk2;
             $self->{parent}->loadPrevious($self);
             $self->setProgress(1.0);
             $self->{parent}->{initializing} = 0;
-            $self->{parent}->set_sensitive(1);
+            $self->{parent}->setSensitive(1);
             $self->{phase} = 3;
             $self->setLabel($self->{parent}->{lang}->{SplashDone});
         }
