@@ -2,7 +2,7 @@ package GCUtils;
 
 ###################################################
 #
-#  Copyright 2005-2006 Tian
+#  Copyright 2005-2007 Tian
 #
 #  This file is part of GCstar.
 #
@@ -118,12 +118,12 @@ sub listToXml
 ';
         foreach $col(@{$_->{col}})
         {
-            $col =~ s/&/&amp;/g;
-            $col =~ s/</&lt;/g;
-            $col =~ s/>/&gt;/g;
-            $col =~ s/"/&quot;/g;
+            (my $newCol = $col) =~ s/&/&amp;/g;
+            $newCol =~ s/</&lt;/g;
+            $newCol =~ s/>/&gt;/g;
+            $newCol =~ s/"/&quot;/g;
             #"
-            $xml .= "    <col>$col</col>\n";
+            $xml .= "    <col>$newCol</col>\n";
         }
         $xml .= '   </line>
 ';
@@ -394,6 +394,7 @@ use File::Basename;
 sub getDisplayedImage
 {
     my ($displayedImage, $default, $file) = @_;
+
     if (!File::Spec->file_name_is_absolute($displayedImage))
     {
         my $dir;
